Anomalous phenomena are observed events which deviate from what is
expected (anomalies) according to existing rules or scientific theory.
Sometimes the anomalous phenomena are expected, but the reason for their
deviation is unclear (See section on anomalies in science). The
scientific study of the field is called anomalistics, though it has been
(incorrectly) associated with pseudoscience.[^1]

Anomalous phenomena as falsification of a theory {#anomalous_phenomena_as_falsification_of_a_theory}
------------------------------------------------

In work beginning in the 1930s, noted philosopher Karl Popper gave
falsifiability a renewed emphasis as a criterion of empirical statements
in science. [^2] Popper noticed that two types of statements
are of particular value to scientists. The first are statements of
observations, such as 'this is a white swan'. Logicians call these
statements singular existential statements since they assert the
existence of some particular thing. They can be parsed in the form:
*There is an x which is a swan, and x is white.*

The second type of statement of interest to scientists categorizes all
instances of something, for example 'all swans are white'. Logicians
call these statements universal. They are usually parsed in the form:
*For all x, if x is a swan, then x is white.*

[[Scientific laws]] are commonly supposed to
be of the second type. Perhaps the most difficult question in the
[[scientific method|methodology of science]] is: How does one
move from observations to laws? How can one validly infer a universal
statement from any number of existential statements?

Inductivist methodology supposed that one can somehow move from a series
of singular existential statements to a universal statement. That is,
that one can move from 'this is a white swan', 'that is a white swan',
and so on, to a universal statement such as 'all swans are white'. This
method is clearly *deductively* invalid since it is always possible
that there may be a non-white swan that has somehow avoided observation.
Yet some philosophers of science claim that science is based on such an
inductive method.

Swans {#swans}
-----

Popper held that science could not be grounded on such an invalid
inference. He proposed falsification as a solution to the problem of
induction. [^3] Popper noticed that although a singular
existential statement such as 'there is a white swan' cannot be used to
affirm a universal statement, it can be used to show that one is false:
the singular existential observation of a black swan serves to show that
the universal statement 'all swans are white' is false - in logic this
is called [[#modus_tollens]]. 'There is a black
swan' implies 'there is a non-white swan' which in turn implies 'there
is something which is a swan and which is not white', hence 'all swans
are white' is false, because that is the same as 'there is *nothing*
which is a swan and which is not white'.

One notices a white swan. From this one can conclude: **At least one
swan is white.** From this, one may wish to infer that: **All swans are
white.** It may be impossible to observe all the swans in the world to
verify that they are all white.

Even so, the statement *all swans are white* is testable by being
falsifiable. For, if in testing many swans, the researcher finds a
single black swan, then the statement *all swans are white* would not be
true; it would be falsified by the counterexample of the single black
swan.

Modus tollens {#modus_tollens}
-------------

The falsification of statements occurs through modus
tollens, via some observation. Suppose some
universal statement U implies an observation O:

*U → O*

An observation conflicting with O, however, is made:

*¬O*

So by modus tollens,

*¬U*

One anomalous phenomenon {#one_anomalous_phenomenon}
------------------------

A statement is only complete insofar as it accurately describes
something free from anomalies. As in the example where the truth of the
statement 'all swans are white' is falsified by the counterexample of
the single black swan, any theory is shown to be falsified by a verified
singular anomaly. For example, the statement 'dinosaurs are extinct'
would be falsified by the discovery of just one remaining dinosaur. The
burden of [[cryptozoologists]], then, would
be to find a single example of a [[cryptid]] to
disprove the statement 'cryptids do not exist'. Of course, as
cryptozoologist Loren Coleman notes, every
time a cryptid is "discovered" (e.g. giant panda, mountain
gorilla, okapi,
coelacanth, megamouth
shark, saola) then that
species becomes part of zoology, and not cryptozoology.

Reversely, [[falsification]] is why various
fields that pursue anomalous phenomena are often seen as not being
worthwhile in mainstream science, or, by extreme
skeptics, as
pseudoscientific. If the aim of science
is to move observations to laws, or to weed out singular existential
statements in favor of
universal statements through testing
against falsifying propositions, anomalies suffer from a missing
component of the [[scientific method]]. A
falsifying proposition of anomalies as deviations from the norm *would
be the norm*. Testing for the norm is seen as redundant.

Limitations {#limitations}
-----------

Although the logic of falsification is valid, it is rather limited.
Nearly any statement can be made to fit the data, so long as one makes
the requisite 'compensatory adjustments'. Popper drew attention to these
limitations in *The Logic of Scientific
Discovery*, in response
to anticipated criticism from Duhem and Carnap. [^3] W. V. Quine expounded this argument in detail, calling
it [[confirmation holism]].[^4] In order to logically falsify a universal,
one must find a true falsifying singular statement. But Popper pointed
out that it is always possible to *change* the universal statement or
the existential statement so that falsification does not occur. On
hearing that a black swan has been observed in Australia, one might
introduce the ad hoc hypothesis, 'all swans are white except those found
in Australia'; or one might adopt another, more cynical view about some
observers, 'the bird watchers are incompetent'. Falsification does not
enable scientists to present a definitive falsification of universal
statements.

These 'compensatory adjustments' have been noticed in criticisms of
[[James Randi]]'s [[One Million Dollar Paranormal Challenge]]. The
challenge offers the proposition that if one can show a single
verifiable anomalous phenomenon (termed paranormal in the challenge),
then one will be awarded the prize of one million dollars. To date, no
one has been able to do so. Some of Randi's detractors claim that the
challenge is insincere and that Randi will ensure he never has to pay
out. The October 1981 issue of [[Fate Magazine]], quoted him as saying "I always have
an out".[^5] Although some critics interpret
this to mean he will never let his organization lose such a challenge,
the "out" could easily be a variation on Popper's idea that it is always
possible to *change* the universal statement or the existential
statement so that falsification does not occur. A statement about the
debatable existence of [[psychic]] phenomena, for
example, can be changed from 'psychic phenomena do not exist' to
'psychic phenomena do not exist in the laboratory under these
conditions', and so on. It should be noted that Randi claims that the
phrase "I always have an out" refers to the fact that he does not allow
test subjects to cheat.[^6]

Anomalies in science {#anomalies_in_science}
--------------------

The occurrence of anomalies in science are often expected, but why the
event deviates from what should occur is not always clear. For example,
in the [[Pioneer anomaly]], observations have
pointed to a deviation in the expected
[[trajectory|trajectories]] of various
spin-stabilized [[unmanned spacecraft]] visiting the [[outer solar system]], notably number 10 and 11 of the
[[Pioneer program]]. After several
observations of the effect, one can reasonably expect the deviation to
occur. However, when all known forces acting on the spacecraft are taken
into consideration, a very small but unexplained force remains. It
causes a constant sunward acceleration of (8.74 ± 1.33) × 10−10 m/s² for
both spacecraft. The reason for this anomaly remains unknown beyond
speculation.

### Known anomalies in science {#known_anomalies_in_science}

* In astronomy, an anomaly of an elliptical orbit, generally measured with respect to an apsis, usually the periapsis:
  * The true anomaly is observed from the primary (i.e., from the [[orbit]]'s focus);
  * The eccentric anomaly is observed from the center of the ellipse, using a projection of the planet's position onto the circumscribing circle; and
  * The mean anomaly is the fraction of an [[orbital period]] that has elapsed, expressed as an angle.
* In an anomaly time series the times are not uniformly spaced.
* In physics, an anomaly is a classical symmetry that is not a symmetry of the quantum theory. Such as:
  * conformal anomaly, 
  * chiral anomaly, 
  * gravitational anomaly, 
  * gauge anomaly,
  * mixed anomaly,
  * global anomaly,
  * parity anomaly.
*  The [[Pioneer anomaly]] is the observed deviation of the trajectories of various spin-stabilised unmanned spacecraft, notably number 10 and 11 of the Pioneer program.

Fortean anomalies {#fortean_anomalies}
-----------------

*Main article: [[Forteana]]*

[[Charles Fort]] (1874 – 1932) is perhaps the
best known researcher of unexplained anomalous phenomena. Fort is said
to have compiled as many as 40,000 notes on unexplained phenomena,
though there were no doubt many more than this. These notes came from
what he called "the orthodox conventionality of Science", which were odd
events originally printed in respected mainstream scientific journals or
newspapers such as *Scientific American*, *The Times*, *Nature and
Science*. From these researches, Fort wrote seven books, though only four
survive. These are: *[[The Book of the Damned]]* (1919), *[[New Lands]]* (1923), *[[Lo!]]* (1931) and
*[[Wild Talents]]* (1932); one book was written
between *New Lands* and *Lo!* but it was abandoned and absorbed into
*Lo!*.

Collectively these phenomena are now referred to as 'Fortean' phenomena,
or [[Forteana]]. Reported events include
[[teleportation]] (a term Fort is generally
credited with coining); [[poltergeist]] events,
falls of frogs, fishes, inorganic materials of an amazing range; [[crop circles]]; unaccountable noises and explosions;
[[Spontaneous combustion|spontaneous fires]];
[[levitation]]; [[ball lightning]] (a term explicitly used by Fort);
[[unidentified flying objects]];
[[mysterious appearances and disappearances]];
giant wheels of light in the oceans; [[entombed animals]]; and animals found outside their
normal ranges (see [[phantom cat]]). He offered
many reports of [[OOPArts]], abbreviation for "out of
place" artifacts: strange items found in unlikely locations. He also is
perhaps the first person to explain strange human appearances and
disappearances by the hypothesis of [[alien abduction]], and was an early proponent of
the [[extraterrestrial hypothesis]].

There are many phenomena in Fort's works which have now been partially
or entirely "recuperated" by mainstream science — ball lightning, for
example, was largely rejected as impossible by the scientific
consensus of Fort's day, but is now recognized as a genuine phenomenon. However, many of Fort's
ideas remain on the very borderlines of "mainstream science." This is
unsurprising, as Fort resolutely refused to abandon the territory beyond
"acceptable" science.

Paranormal anomalies {#paranormal_anomalies}
--------------------

*Main article: [[Paranormal phenomena]]*

Purported phenomena with explanations considered to be outside the scope
of conventional science can be classified as [[paranormal phenomena]]. Because these anomalies are
difficult to explain in terms of science, their existence is often
challenged by skeptics. Even when there is a
widespread belief that the anomaly is real, explanations for the anomaly
are subjected to frequent debate and controversy.

Within the umbrella term of paranormal, there are subclasses of
phenomena as well. For example, phenomena studied in the limited field
of [[parapsychology]] would be a subclass,
which in turn can be divided into three classes of its own:

-   Mental phenomena: often described as [[extrasensory perception]], this class includes
    unusual mental states or abilities, such as
    [[telepathy]],
    [[clairvoyance]] and
    [[precognition]].
-   Physical phenomena: this class includes unusual physical
    occurrences, such as [[psychokinesis]],
    [[poltergeists]],
    [[stigmata]], [[paranormal vanishing]], [[reality shifts]] or
    [[materializations]].
-   Survival phenomena: this class deals with the survival of
    consciousness after physical death and includes
    [[ghosts]], [[hauntings]],
    [[out-of-body experiences]] (OBEs),
    [[reincarnation]] and [[near-death experiences]] (NDEs).

Phenomena considered outside the scope of parapsychology, but possibly
within the scope of paranormal includes:

-   [[abduction phenomenon|alien abduction experiences]]
-   [[cryptozoology]]
-   [[déjà vu]]
-   [[folie à deux]]
-   [[spontaneous human combustion]]
-   [[UFOs]]

To be classified as paranormal, a phenomenon must lack a scientific
explanation. When an anomaly receives a valid scientific explanation, it
becomes "perinormal." Perinormal is a term that has been suggested to
describe previously unknown forces which at first appeared to be
paranormal and were later verified scientifically. For example, while
the idea of stones falling from the sky was once considered anomalous,
[[meteorites]] are now acknowledged and well
understood.

References {#references}
----------

-   Classical civilization included unique signs and prodigies of nature
    in works of [[paradoxography]] such as *The
    Phaenomena* (240 BC) by Aratus of Soli.
-   Inoue Enryo, a Japanese educator and philosopher, authored the
    six-volume *The Study of Yōkai* (妖怪学). As a result, he was best
    known as Dr. Ghost (お化け博士) or Dr. Yōkai (妖怪博士).
-   [[Charles Fort]], in his four works on
    anomalies (*The Book of the Damned, New Lands, Lo!,* and *Wild
    Talents*) lambasted and ridiculed the scientists of his day for
    their shortsightedness. Some of the anomalies listed in his work
    have been explained and incorporated into modern science, while
    others continue to be unexplained.
-   [[International Fortean Organization]],
    successor to the original [[Fortean Society]], sponsors the annual
    [[FortFest]], the world's first, most prestigious
    and longest-running conference on anomalous phenomena.
-   William R. Corliss' *Science Frontiers* has covered reports in the scientific literature
    regarding anomalies for years. He, through his Sourcebook Project,
    has published a large body of reports collected in many of the
    scientific disciplines.
-   Leonard George, a psychologist who
    specializes in anomalous phenomena, compiled an authoritative
    encyclopedia of unusual experiences, activities, and beliefs in his
    1995 book *Alternative Realities*.
-   *[[Fortean Times]]*, a British monthly
    magazine, continues in the spirit of Fort's work by publishing
    reports of anomalous phenomena and longer investigative articles.
-   *The Anomalist*, edited by Patrick
    Huyghe and Dennis Stacy, is another magazine/journal devoted to the
    study of anomalies (which may be called [[anomalistics]]).
-   Strange Magazine is another magazine devoted to the study of
    anomalies in the spirit of Fort's work.
-   [[Fate magazine]], with the slogan "True
    Reports of the Strange and Unknown" has been published continuously
    since 1948, and is the longest-running publication of its kind.
-   The [[Society for Psychical Research]] - Founded in
    London in 1882

Further reading {#further_reading}
---------------

-   [[Charles Fort|Fort, Charles]] (1975). The Complete Books
    of Charles Fort (paperback), Dover Publications, 1126 pages. ISBN
    0-486-23094-5.
-   Corliss, William R. (1983).
    Handbook of Unusual Natural Phenomena: Eyewitness Accounts of
    Nature's Greatest Mysteries (paperback), Anchor Press, Doubleday,
    423 pages. ISBN 0-385-14754-6.
-   Rickard, Bob; [[John Michell|Michell, John]] (2000). The
    Rough Guide to Unexplained Phenomena (paperback), Rough Guides, 400
    pages. ISBN 1-85828-589-5.
-   Dash, Mike (1997). Borderlands: The Ultimate
    Exploration of the Unknown (paperback), Dell, 544 pages. ISBN
    0-440-23656-8.
-   [[Remote Viewing]] Secrets, Joseph
    McMoneagle, Hampton Roads, 2000,
    paperback, 296 pages, ISBN 1-57174-159-3
-   The Conscious Universe, Dean Radin PhD,
    Harper, 1997, hardback, 362 pages, ISBN 0-06-251502-0
-   [[Channeling]]: Investigations on Receiving
    Information from Paranormal Sources. John Klimo, St. Martins
    Press, 1987. ISBN 0-87477-431-4
-   Mr. Wilson's Cabinet Of Wonder: Pronged Ants, Horned Humans, Mice on
    Toast, and Other Marvels of Jurassic Technology, Lawrence Weschler,
    1996, trade paperback, 192 pages, ISBN 0-679-76489-5 
-   Patrick Grim, ed. Philosophy of Science and the Occult, 1982, SUNY,
    ISBN 0-87395-573-0

Notes {#notes}
-----

[^1]: James E. Alcock, Behavioral and Brain Sciences (1998), 21: 303-303 Cambridge University Press
[^2]: Hacohen, Malachi Haim (2002). Karl Popper - The Formative Years, 1902-1945: Politics and Philosophy in Interwar Vienna. Cambridge, UK: Cambridge University Press, 206-208. ISBN 0-521-89055-1.
[^3]: Popper, Karl Raimund (2002). The Logic of Scientific Discovery. Cambridge, UK: Routledge, 3-25. ISBN 0-415-27843-0.
[^4]: Esfeld, Michael (2001). Holism in Philosophy of Mind and Philosophy of Physics. Boston: Kluwer Academic Publishers. ISBN 0-7923-7003-1.
[^5]: Rawlins, Dennis (October 1981). ""sTARBABY"". FATE Magazine (No. 34). Reprinted in "sTARBABY". Centre Universitaire de Recherche en Astrologie (The International Astrology Research Center). Retrieved on 2006-09-09.
[^6]: Mike Hutchinson (2000-01-22). "Geller: the "after bending" effect". sci.skeptic. (Google Groups). Retrieved on 2006-11-28.