**Clairvoyance** (from 17th century French
with *clair* meaning "clear" and *voyance* meaning "visibility") is
the apparent ability to gain information about an object, location or
physical event through means other than the known human
senses,[^1][^2] a form of [[extra-sensory perception]]. A person said to have
the ability of clairvoyance is referred to as a *clairvoyant* ("one who
sees clear").

Claims for the existence of [[paranormal]]
[[psychic]] abilities such as clairvoyance are highly
controversial. [[Parapsychology]] explores this
possibility, but the existence of the paranormal is not accepted by the
scientific community.

Usage
-----

Within [[parapsychology]], clairvoyance is used
exclusively to refer to the transfer of information that is both
contemporary to, and hidden from, the clairvoyant. It is differentiated
from [[telepathy]] in that the information is said
to be gained directly from an external physical source, rather than
being transferred from the mind of one individual to another.[^3]

Outside of parapsychology, clairvoyance is often used to refer to other
forms of [[Anomalous cognition]], most
commonly the perception of events that have occurred in the past, or
which will occur in the future (known as
[[retrocognition]] and
[[precognition]] respectively),[^4] or to
refer to communications with the dead (see
[[mediumship]]).

Clairvoyance is related to [[remote viewing]],
although the term "remote viewing" itself is not as widely applicable
to clairvoyance because it refers to a specific controlled process.

Status of clairvoyance {#status_of_clairvoyance}
----------------------

Within the field of parapsychology, there is a consensus that some
instances of clairvoyance are verifiable.[^6][^7] There is also a
measured level of belief from amongst the general public, with the
portion of the US population who believe in clairvoyance varying between
1/4 and 1/3 over the 15 year period from 1990 to 2005.[^4]

The concept of clairvoyance gained some support from the US and Russian
governments both during and after the Cold War,
and both governments made several attempts to harness it as an
intelligence gathering tool.[^9]

According to skeptics, clairvoyance is the result of fraud,
self-[[delusion]][^4], [[Forer_effect|Barnum effects]], [[Confirmation bias|confirmatory biases]], or failures to appreciate the
base rate of chance occurrences. For example, in a scientific experiment
of clairvoyance, a purported clairvoyant participant will inevitably
make correct guesses some of the time (i.e., during some of the trials
within the same experiment), simply because of chance. Furthermore,
because of the nature of the statistical tests used by experimenters, a
very small proportion of all experiments conducted will yield an overall
statistically significant result (suggesting that clairvoyance took
place at above-chance levels), again simply because of chance. A proper
summary of the experimental evidence on clairvoyance should include a
summary of all experiments that were conducted, taking into account
their probabilities of turning out false positive and false negative
results, and making sure that studies are not included in the review
selectively. Some researchers on clairvoyance have tended to
purposefully exclude negative findings from their reviews [^11], thus
biasing their own conclusions.

Clairvoyance and related phenomena throughout history {#clairvoyance_and_related_phenomena_throughout_history}
-----------------------------------------------------

There have been anecdotal reports of
clairvoyance and 'clear' abilities throughout history in most
cultures. Often clairvoyance has been associated with religious or
shamanic figures, offices and practices. For
example, ancient Hindu religious texts list clairvoyance amongst other
forms of 'clear' experiencing, as siddhis, or
'perfections', skills that are yielded through appropriate meditation
and personal discipline. But a large number of anecdotal accounts of
clairvoyance are of the spontaneous variety among the general populace.
For example, many people report seeing a loved one who has recently died
before they have learned by other means that their loved one is
deceased. While anecdotal accounts do not provide scientific proof of
clairvoyance, such common experiences continue to motivate research into
such phenomena.

The earliest record of somnambulistic clairvoyance is credited to the
Marquis de Puységur, a follower of
Mesmer, who in 1784 was treating a local dull-witted peasant named
Victor Race. During treatment, Race reportedly would go into trance and
undergo a personality change, becoming fluent and articulate, and giving
diagnosis and prescription for his own disease as well as those of
others. When he came out of the trance state he would be unaware of
anything he had said or done. This behavior is somewhat reminiscent of
the reported behaviors of the 20th century medical clairvoyant and
psychic [[Edgar Cayce]]. It is reported that
although Puységur used the term 'clairvoyance', he did not think of
these phenomena as "[[paranormal]]", since he
accepted mesmerism as one of the natural sciences.

Clairvoyance was a reported ability of some mediums during the
[[spiritualist]] period of the late 19th and
early 20th centuries and was one of the phenomena studied by members of
the [[Society for Psychical Research]] (SPR). Psychics of
many descriptions have claimed clairvoyant ability up to the present
day.

While experimental research into clairvoyance began with SPR
researchers, experimental studies became more systematic with the
efforts of [[J. B. Rhine]] and his
associates at Duke University, and such
research efforts continue to the present day. Perhaps the best-known
study of clairvoyance in recent times was the US government-funded
[[remote viewing]] project at
Stanford Research Institute/Science Applications International Corporation
during the 1970s through the mid-1990s.

Some parapsychologists have proposed that our different functional
labels (clairvoyance, [[telepathy]],
[[precognition]], etc.) all refer to one basic
underlying mechanism, although there is not yet any satisfactory theory
for what that mechanism may be.

Parapsychological research {#parapsychological_research}
--------------------------

Parapsychological research studies of [[remote
viewing]] and clairvoyance have produced
favorable results significantly above chance, and meta-analysis of these
studies increases the significance. For instance, at the Stanford
Research Institute, in 1972, Harold Puthoff
and Russell Targ initiated a series of human
subject studies to determine whether participants (the *viewers* or
*percipients*) could reliably identify and accurately describe salient
features of remote locations or *targets*. In the early studies, a human
*sender* was typically present at the remote location, as part of the
experiment protocol. A three-step process was used, the first step being
to randomly select the target conditions to be experienced by the
senders. Secondly, in the viewing step, participants were asked to
verbally express or sketch their impressions of the remote scene.
Thirdly, in the judging step, these descriptions were matched by
separate judges, as closely as possible, with the intended targets. The
term [[remote viewing]] was coined to describe
this overall process.

In order to explore the nature of remote viewing channel, the viewer in
some experiments was secured in a double-walled copper-screened [[Faraday cage]]. Although this provided attenuation of
radio signals over a broad range of frequencies, the researchers found
that it did not alter the subject's remote viewing capability. They
postulated that [[extremely low frequency]] (ELF) propagation might
be involved, since Faraday cage screening is less effective in the ELF
range. Such a hypothesis had previously been put forward by telepathy
researchers in the Soviet Union.[^12]

The first paper by Puthoff and Targ on psychic research to appear in a
mainstream peer-reviewed scientific journal was published in
Nature in March 1974; in it, the team
reported some degree of remote viewing success.[^13] One of the
individuals involved in these initial studies at SRI was Uri
Geller, a well-known celebrity psychic at the
time. The research team reported witnessing some of Geller's trademark
metal spoon-bending performances, but admitted that they were unable to
conduct adequately controlled experiments to confirm any paranormal
hypothesis about them.

[[Electroencephalography]] (EEG)
techniques were also used by team to examine ESP phenomena. In these
investigations, a sender, who was isolated in a visually opaque,
electrically and acoustically shielded chamber, was stimulated at random
by bursts of strobe-light flickers The experimenters reported that, for
one receiver, differential alpha block on control and stimulus trials
were observed, which showed that some information transfer had occurred.
In contrast, this person's expressed statements of when the stimulus
occurred were no different than that which would be expected by chance.
The researches were unable to identify the physical parameters by which
the EEG effect was mediated.[^14]

After the publication of these findings, various attempts to replicate
the remote viewing findings were quickly carried out. Several of these
follow-up studies, which involved viewing in group settings, reported
some limited success. They included the use of face-to-face
groups,[^15][^16] and remotely-linked groups using computer
conferencing.[^17]

The various debates in the mainstream scientific literature prompted the
editors of 'Proceedings of the IEEE' to invite Robert
Jahn, then Dean of the School of Engineering at
Princeton University, to write a
comprehensive review of psychic phenomena from an engineering
perspective. His paper[^18], published in February 1982, includes
numerous references to remote viewing replication studies at the time.

Clairvoyance experiments involving [[Zener cards]]
currently exist on the internet. One such online system, the Anima
Project[^19], gathers user results into a master database which is then
analyzed using a variety of statistical techniques.

Skepticism
----------

Parapsychological research is regarded by critics as a
pseudoscience.[^20] In 1988, the US National
Research Council concluded that
it "...finds no scientific justification from research conducted over
a period of 130 years, for the existence of parapsychological
phenomena."[^21]

Skeptics say that if clairvoyance
were a reality it would have become abundantly clear. They also contend
that those who believe in [[paranormal]] phenomena
do so for merely psychological reasons. According to David G. Myers
(*Psychology,* 8th ed.):

> The search for a valid and reliable test of clairvoyance has resulted
> in thousands of experiments. One controlled procedure has invited
> 'senders' to telepathically transmit one of four visual images to
> 'receivers' deprived of sensation in a nearby chamber (Bem &
> Honorton, 1994). The result? A reported 32 percent accurate response
> rate, surpassing the chance rate of 25 percent. But follow-up studies
> have (depending on who was summarizing the results) failed to
> replicate the phenomenon or produced mixed results (Bem & others,
> 2001; Milton & Wiseman, 2002; Storm, 2000, 2003).\
> \
> One skeptic, magician [[James  Randi]], has a
> longstanding offer---now U.S. \$1 million---"to anyone who proves a
> genuine psychic power under proper observing conditions" (Randi,
> 1999). French, Australian, and Indian groups have parallel offers of
> up to 200,000 euros to anyone with demonstrable paranormal abilities
> (CFI, 2003). Large as these sums are, the scientific seal of approval
> would be worth far more to anyone whose claims could be authenticated.
> To refute those who say there is no ESP, one need only produce a
> single person who can demonstrate a single, reproducible ESP
> phenomenon. So far, no such person has emerged. Randi's offer has been
> publicized for three decades and dozens of people have been tested,
> sometimes under the scrutiny of an independent panel of judges. Still,
> nothing. "People's desire to believe in the paranormal is stronger
> than all the evidence that it does not exist." Susan
> Blackmore, "Blackmore's first law", 2004.

Other related terms {#other_related_terms}
-------------------

The words "clairvoyance" and "psychic" are often used to refer to
many different kinds of paranormal sensory experiences, but there are
more specific names:

### Clairsentience (feeling/touching) {#clairsentience_feelingtouching}

In the field of parapsychology, **clairsentience** is a form of
[[extra-sensory perception]] wherein
a person acquires [[psychic]] knowledge primarily by
means of feeling.[^22] The word is from the French clair, "clear," +
sentience, "feeling," and is ultimately derived from the Latin clarus,
"clear," + sentiens, derived from sentire, "to feel".

In addition to parapsychology, the term also plays a role in some
religions. For example: clairsentience is one of the six human special
functions mentioned or recorded in Buddhism. It
is an ability that can be obtained at advanced meditation level.
Generally the term refers to a person who can feel the vibration of
other people. There are many different degrees of clairsentience ranging
from the perception of diseases of other people to the thoughts or
emotions of other people. The ability differs from [[third eye]] in that this kind of ability cannot have a
vivid picture in the mind. Instead, a very vivid feeling can form.

[[Psychometry]] is related to clairsentience. The
word stems from *psyche* and *metric*, which means "to measure with the
mind".

### Clairaudience (hearing/listening) {#clairaudience_hearinglistening}

In the field of parapsychology, **clairaudience** \[from late 17th
century French *clair* (clear) & audience (hearing)\] is a form of
[[extra-sensory perception]] wherein
a person acquires information by [[paranormal]]
auditory means. It is often considered to be a form of
clairvoyance.[^23] Clairaudience is essentially the ability to hear in a
[[paranormal]] manner, as opposed to paranormal
seeing (clairvoyance) and feeling
([[clairsentience]]). Clairaudient people have
[[psi]]-mediated hearing. Clairaudience
may refer not to actual perception of sound, but may instead indicate
impressions of the "inner mental ear" similar to the way many people
think words without having auditory impressions. But it may also refer
to actual perception of sounds such as voices, tones, or noises which
are not apparent to other humans or to recording equipment. For
instance, a clairaudient person might claim to hear the voices or
thoughts of the spirits of persons who are deceased. Clairaudience may
be positively distinguished from the voices heard by the mentally ill
when it reveals information unavailable to the clairaudient person by
normal means (including [[cold reading]] or other
magic tricks), and thus may be termed "[[psychic]]"
or
[[paranormal]]. [Citation Needed]

### Clairalience (smelling) {#clairalience_smelling}

In the field of parapsychology, **clairalience** \[presumably from late
17th century French *clair* (clear) & alience (smelling)\] is a form of
[[extra-sensory perception]] wherein
a person acquires psychic knowledge primarily by means of smelling.[^24]

### Claircognizance (knowing) {#claircognizance_knowing}

In the field of parapsychology, **claircognizance** \[presumably from
late 17th century French *clair* (clear) & *cognizance* (\<
Middle English *cognisaunce* \<
Old French *conoissance*, knowledge)\] is a form of
[[extra-sensory perception]] wherein
a person acquires psychic knowledge primarily by means of intrinsic
knowledge. It is the ability to know something without knowing how or
why you know it.

### Clairgustance (tasting) {#clairgustance_tasting}

In the field of parapsychology, **clairgustance** is defined as a form
of [[extra-sensory perception]] that
allegedly allows one to taste a substance without putting anything in
one's mouth. It is claimed that those who possess this ability are able
to perceive the essence of a substance from the spiritual or ethereal
realms through taste. [Citation Needed]

See also {#see_also}
--------

-   [[Anomalous cognition]]
-   [[Astral projection]]
-   [[Near-death experience]]
-   [[Out-of-body experience]]
-   [[Paranormal phenomena]]
-   [[Parapsychology]]
-   [[Plane (metaphysics)]]
-   [[Postdiction]] (retroactive clairvoyance)


Further reading {#further_reading}
---------------

-   ["All that clairvoyant stuff -- I don't see it myself: A new law against mediums would not work"](http://www.timesonline.co.uk/tol/comment/columnists/daniel_finkelstein/article1637254.ece) by Daniel Finkelstein, *The Times*, April 11, 2007.
-   *Mental Radio* by Upton Sinclair, 1929. Preface by Albert Einstein.

[[]]
[^1]: <http://mw1.merriam-webster.com/dictionary/clairvoyance>
    Merriam-Webster Online dictionary, Retrieved Oct 5, 2007 "1: the
    power or faculty of discerning objects not present to the senses 2:
    ability to perceive matters beyond the range of ordinary perception:
    penetration"

[^2]: [Britannica Online Encyclopedia](http://www.britannica.com/ebc/article-9364105),
    Retrieved Oct 7, 2007. The ESP entry includes clairvoyance

[^3]: [Glossary of Parapsychological terms -
    Clairvoyance](http://parapsych.org/glossary_a_d.html#c) ---
    [Parapsychological
    Association](Parapsychological_Association "wikilink") (2007-04-27)

[^4]: Carrol, Robert (2003),
    "[Clairvoyance](http://www.skepdic.com/clairvoy.html)" - *Skeptics
    Dictionary*, Wiley, ISBN 0471272426

[^6]: "[What is
    parapsychology?](http://parapsych.org/faq_file1.html#4)", FAQ -
    Parapsychological Association ([2007-02-03](2007-02-03 "wikilink"))

[^7]: "[What is the state-of-the-evidence for
    psi?](http://parapsych.org/faq_file3.html#20)", FAQ -
    Parapsychological Association ([2007-02-03](2007-02-03 "wikilink"))

[^9]: Waller, Douglas (1995-12-11), "The Vision Thing",
    *[Time](Time_(magazine) "wikilink")*, p.45

[^11]: Tart (1983) Journal of the American Society for Psychical
    Research

[^12]: Kogan I, "Information theory analysis of telepathic
    communication experiments", Radio Engineering, v23, March 1968, p
    122.

[^13]: Targ R & Puthoff H, "Information transmission under conditions
    of sensory shielding", Nature, 251, October 18 1974, pp 602-607.

[^14]: Rebert C & Turner A, "EEG spectrum analysis techniques applied
    to the problem of psi phenomena", Behavioral Neuropsychiatry,
    v6(1-12), Apr 1974 Apr-Mar 1975, pp18-24

[^15]: Hastings A & Hurt D, "A Confirmatory Remote Viewing in a Group
    Setting" Proceedings of the IEEE, Vol 64, No 10, p 1544-1545,
    October 1976.

[^16]: Whitson T, Bogart D, Palmer J, & Tart C, "Preliminary
    Experiments in Remote Viewing", Proceedings of the IEEE, Vol 64, No
    10, p 1550-1551, October 1976.

[^17]: Vallee J, Hastings A, & Askevold G, "Remote Viewing Experiments
    Through Computer Conferencing", Proceedings of the IEEE, Vol 64, No
    10, p 1551-1552, October 1976.

[^18]: Jahn R, "The Persistent Paradox of Psychic Phenomena: An
    Engineering Perspective", Proceedings of the IEEE, 7 2, Feb 1982,
    pp 136-170

[^19]: `{{cite web |url=http://www.animaproject.org |title=The Anima Project |accessdate=2008-04-08 }}`{=mediawiki}

[^20]: Marks, D.F. (2000). *The Psychology of the Psychic* (2nd Ed.) New
    York: Prometheus Books. ISBN 1573927988

[^21]: [*An Encyclopedia of Claims, Frauds, and Hoaxes of the Occult and
    Supernatural*](http://www.randi.org/encyclopedia/parapsychology.html)
    James Randi

[^22]: [Parapsychological Association historical terms
    glossary](http://parapsych.org/historical_terms.html), retrieved
    [December 17](December_17 "wikilink"), [2006](2006 "wikilink")

[^23]: [Parapsychological Association website, Glossary of Key Words
    Frequently Used in
    Parapsychology](http://parapsych.org/historical_terms.html),
    Retrieved [January 24](January_24 "wikilink"),
    [2006](2006 "wikilink")

[^24]: [Supernatural
    Glossary](http://www.ghostvillage.com/resources/2003/resources_10132003.shtml)
