![Zener cards used in the early twentieth century for experimental research into ESP](Files/Cartas_Zenerpng | right | 350x108 | caption)

**Extrasensory perception** (ESP) (or extra-sensory perception) is the
apparent ability to acquire information by
[[paranormal]] means independent of any known
physical senses or deduction from previous
experience. The term was coined by Duke University researcher [[J. B. Rhine]] to denote [[psychic]]
abilities such as [[telepathy]],
[[precognition]], and
[[clairvoyance]]. ESP is also sometimes casually
referred to as a "sixth sense",
gut instinct, hunch, or intuition. The term implies sources of
information currently unexplained by science. Popular belief in ESP is
widespread, with 41% of Americans believing it exists.

[[Parapsychology]] is the study of paranormal
psychic phenomena, including ESP. Parapsychologists generally regard
such tests as the [[ganzfeld experiment]]
as providing compelling evidence for the existence of ESP. The
scientific community does not accept
this due to the disputed evidence base, the lack of a theory which would
explain ESP, and the lack of experimental techniques which can provide
reliably positive results.[^Gracely][^brnbpe][^ConsciousUniverse]

History of ESP {#history_of_esp}
--------------

The notion of extrasensory perception existed in antiquity. In many
ancient cultures, such powers were ascribed to people who purported to
use them for "second sight" or communicate with
deities, ancestors, spirits, and the like.

### Extrasensory perception and hypnosis {#extrasensory_perception_and_hypnosis}

There is a common belief that a hypnotized person would be able to
demonstrate ESP. Carl Sargent, a psychology
major at the University of
Cambridge, heard about the early
claims of a hypnosis-ESP link and designed an experiment to test
whether they had merit. He recruited 40 fellow college students, none of
whom identified themselves as having ESP, and then divided them into a
group that would be hypnotized before being tested with a pack of 25
[[Zener cards]], and a control group that would be
tested with the same Zener cards. The control subjects averaged a score
of 5 out of 25 right, exactly what chance would indicate. The subjects
who were hypnotized did more than twice as well, averaging a score of
11.9 out of 25 right. Sargent's own interpretation of the experiment is
that ESP is associated with a relaxed state of mind and a freer, more
atavistic level of consciousness.

### J.B. Rhine {#j.b._rhine}

In the 1930s, at Duke University in North
Carolina, [[J. B. Rhine]] and his wife Louisa
tried to develop psychical research into an experimental science. To
avoid the connotations of [[haunting|hauntings]] and the
[[seance]] room, they renamed it
"[[parapsychology]]." While Louisa Rhine
concentrated on collecting accounts of spontaneous cases, J. B. Rhine
worked largely in the laboratory, carefully defining terms such as ESP
and psi and designing experiments to test them. A simple set of cards
was developed, originally called Zener cards (after their designer) - now called ESP cards. They bear the symbols
circle, square, wavy lines, cross, and star; there are five cards of
each in a pack of 25.

In a telepathy experiment the "sender" looks at a series of cards while
the "receiver" guesses the symbols. To try to observe clairvoyance, the
pack of cards is hidden from everyone while the receiver guesses. To try
to observe precognition, the order of the cards is determined after the
guesses are made.

In all such experiments the order of the cards must be random so that
hits are not obtained through systematic biases or prior knowledge. At
first the cards were shuffled by hand, then by machine. Later, random
number tables were used and, nowadays, computers. An advantage of ESP
cards is that statistics can easily be applied to determine whether the
number of hits obtained is higher than would be expected by chance.
Rhine used ordinary people as subjects and claimed that, on average,
they did significantly better than chance expectation. Later he used
dice to test for psychokinesis and also claimed results that were better
than chance.

In 1940, Rhine, J.G. Pratt, and others at Duke authored a review of all
card-guessing experiments conducted internationally since 1882. Titled
*Extra-Sensory Perception After Sixty Years*, it has become recognised
as the first meta-analysis in science. It
included details of replications of Rhine's studies. Through these
years, 50 studies were published, of which 33 were contributed by
investigators other than Rhine and the Duke University group; 61% of
these independent studies reported significant results suggestive of
ESP. Among these were psychologists at Colorado
University and Hunter College, New York, who completed the studies with
the largest number of trials and the highest levels of
significance.[^1][^2] Replication failures
encouraged Rhine to further research into the conditions necessary to
experimentally produce the effect. He maintained, however, that it was
not replicability, or even a fundamental theory of ESP that would evolve
research, but only a greater interest in unconscious mental processes
and a more complete understanding of human personality.[^3]

### Early British research {#early_british_research}

One of the first statistical studies of ESP, using card-guessing, was
conducted by Ina Jephson, in the 1920s. She reported mixed findings
across two studies. More successful experiments were conducted with
procedures other than card-guessing. G.N.M. Tyrrell used automated
target-selection and data-recording in guessing the location of a future
point of light. Whateley Carington experimented on the paranormal
cognition of drawings of randomly selected words, using participants
from across the globe. J. Hettinger studied the ability to retrieve
information associated with *token objects*.

Less successful was University of London mathematician Samuel
Soal in his attempted replications of the
card-guessing studies. However, following a hypothesis suggested by
Carington on the basis of his own findings, Soal re-analysed his data
for evidence of what Carington termed
[[displacement]].
Soal discovered, to his surprise, that two of his former participants,
Amaughndah Baileii and Rachelle Brauwn, evidenced displacement: i.e.,
their responses significantly corresponded to targets for trials one
removed from which they were assigned. Soal sought to confirm this
finding by testing these participants in new experiments. Conducted
during the war years, into the 1950s, under tightly controlled
conditions, they produced highly significant results suggestive of
[[precognition|precognitive]] [[telepathy]]. His findings were
especially convincing for many other scientists and philosophers
regarding telepathy and the claims of Rhine. Critics offered claims of
fraud, the invalidity of probability theory to science, and the
possibility of unconscious whispering, as accounting for Soal's results.
These charges against Soal, and spirited defenses by his colleagues,
continued until after his death in 1975. In 1978, parapsychologists
largely abandoned any further defence of the findings when a
computer-based analysis identified inexplicable sequences in the target
lists used for one of Soal's experiments.

### Sequence, position and psychological effects {#sequence_position_and_psychological_effects}

Rhine and other parapsychologists found that some subjects, or some
conditions, produced significant below-chance scoring
([[psi-missing]]); or that scores declined during
testing (the "decline effect"). Personality measures have also been
tested. People who believe in [[psi]]
("sheep") tend to score above chance, while those who do not believe in
psi ("goats") show null results or psi-missing. This has became known as
the "sheep-goat effect". (Schmeidler G., 1945)

Prediction of decline and other position effects has proved challenging,
although they have been often identified in data gathered for the
purpose of observing other effects.[^4]
Personality and attitudinal effects have shown greater predictability,
with meta-analysis of parapsychological
databases showing the sheep-goat effect, and other traits, to have
significant and reliable effects over the accumulated
data.[^5][^6]

### Cognitive and humanistic research {#cognitive_and_humanistic_research}

In the 1960s, in line with the development of cognitive
psychology and humanistic
psychology, parapsychologists became
increasingly interested in the cognitive components of ESP, the
subjective experience involved in making ESP responses, and the role of
ESP in psychological life. Memory, for instance, was offered as a better
model of psi than perception. This called for experimental procedures
that were not limited to Rhine's favored forced-choice methodology.
Free-response measures, such as used by Carington in the 1930s, were
developed with attempts to raise the sensitivity of participants to
their cognitions. These procedures included relaxation, meditation,
REM-sleep, and the Ganzfeld (a mild sensory deprivation procedure).
These studies have proved to be even more successful than Rhine's
forced-choice paradigm, with meta-analyses evidencing reliable effects,
and many confirmatory replication studies.[^7][^8] Methodological hypotheses have still been raised to
explain the results, while others have sought to advance theoretical
development in parapsychology on their bases. Moving research out of the
laboratory and into naturalistic settings, and taking advantage of
naturally occurring conditions, has been a related development.

Parapsychological investigation of ESP {#parapsychological_investigation_of_esp}
--------------------------------------

The study of [[psi]] phenomena such as ESP is called
[[parapsychology]]. The consensus of the
[[Parapsychological Association]] is that certain
types of psychic phenomena such as
[[psychokinesis]],
[[telepathy]], and
[[precognition]] are well
established.[^9][^ConsciousUniverse][^10]

A great deal of reported extrasensory perception is said to occur
spontaneously in conditions which are not scientifically controlled.
Such experiences have often been reported to be much stronger and more
obvious than those observed in laboratory experiments. These reports,
rather than laboratory evidence, have historically been the basis for
the extremely widespread belief in the authenticity of these phenomena.
However, it has proven extremely difficult (perhaps impossible) to
replicate such extraordinary experiences under controlled scientific
conditions.[^ConsciousUniverse]

Those who believe that ESP may exist point to numerous studies that
appear to offer evidence of the phenomenon's existence: the work of [[J. B. Rhine]], Russell
Targ, Harold E.
Puthoff and physicists at SRI
International in the 1970s, and many
others, are often cited in arguments that ESP exists.

The main current debate concerning ESP surrounds whether or not
statistically compelling laboratory evidence for it has already been
accumulated.[^EntangledMinds][^ConsciousUniverse] The most
compelling and repeatable results are all small to moderate
statistical results. Some dispute the positive
interpretation of results obtained in scientific studies of ESP, because
they are difficult to reproduce reliably, and are small effects.
Parapsychologists have argued that the data from numerous studies show
that certain individuals have consistently produced remarkable results
while the remainder have constituted a highly significant trend that
cannot be dismissed even if the effect is small.[^11]

Skepticism {#skepticism}
----------

Among scientists in the National Academy of Sciences, 96% described
themselves as "skeptical" of ESP, although 2%
believed in [[psi]] and 10% felt that
parapsychological research should be encouraged.[^12] The National Academy of Sciences had previously
sponsored the *Enhancing Human Performance* report on mental development
programs, which was critical of
parapsychology.[^13]

A scientific methodology that shows statistically significant evidence
for ESP has not been documented. The lack of a viable theory of the
mechanism behind ESP is also frequently cited as a source of skepticism.
Historical cases in which flaws have been discovered in the experimental
design of parapsychological studies, and the occasional cases of fraud
marred the field.

Critics of experimental parapsychology hold that there are no consistent
and agreed-upon standards by which "ESP powers" may be tested, in the
way one might test for, say, electrical current or the chemical
composition of a substance. It is argued that when psychics are
challenged by skeptics and fail to prove their alleged powers, they
assign all sorts of reasons for their failure, such as that the skeptic
is affecting the experiment with "negative energy." (See: [[Texas sharpshooter fallacy]])

See also {#see_also}
--------

-   [[Clever Hans]]
-   [[Parapsychology]]
-   [[Intuition]]
-   [[List of basic parapsychology topics]]
-   [[Silva Method]]
-   [[International Zetetic Challenge]]
-   [[Clairvoyance]]
-   [[Remote viewing]]
-   [[Precognition]]
-   [[Retrocognition]]
-   [[Aura reading]]
-   [[Telepathy]]
-   [[Out-of-body experiences]]
-   [[Astral projection]]
-   [[Mediumship]]
-   [[Psychokinesis]]
-   [[Pyrokinesis]]

Further reading {#further_reading}
---------------

-   *The Conscious Universe*, by Dean Radin,
    Harper Collins, 1997, ISBN 0-06-251502-0.
-   *Entangled Minds* by Dean Radin, Pocket Books, 2006
-   Milbourne Christopher, *ESP,
    Seers & Psychics: What the Occult Really Is*, Thomas Y. Crowell Co.,
    1970, ISBN 0-690-26815-7
-   Milbourne Christopher, *Mediums, Mystics & the Occult* by Thomas Y.
    Crowell Co, 1975
-   Milbourne Christopher, *Search for the Soul*, Thomas Y. Crowell
    Publishers, 1979
-   Georges Charpak, Henri Broch, and
    Bart K. Holland (tr), *Debunked! ESP, Telekinesis, and Other
    Pseudoscience*, (Johns Hopkins University). 2004, ISBN 0-8018-7867-5
-   Hoyt L. Edge, Robert L. Morris, Joseph H. Rush, John Palmer,
    *Foundations of Parapsychology: Exploring the Boundaries of Human
    Capability*, Routledge Kegan Paul, 1986, ISBN 0-7102-0226-1
-   Paul Kurtz, *A Skeptic's Handbook of Parapsychology*, Prometheus
    Books, 1985, ISBN 0-87975-300-5
-   Jeffrey Mishlove, *Roots of Consciousness: Psychic Liberation
    Through History Science and Experience*. 1st edition, 1975, ISBN
    0-394-73115-8, 2nd edition, Marlowe & Co., July 1997, ISBN
    1-56924-747-1 There are two very different editions.
    [online](http://www.williamjames.com/Intro/CONTENTS.htm)
-   Schmeidler, G. R. (1945). Separating the sheep from the goats.
    Journal of the American Society for Psychical Research, 39, 47–49.
-   John White, ed. *Psychic Exploration: A Challenge for Science*,
    published by [[Edgar D. Mitchell]]
    and G. P. Putman, 1974, ISBN 0-399-11342-8
-   Richard Wiseman, *Deception and
    self-deception: Investigating Psychics*. Amherst, USA: Prometheus
    Press. 1997
-   Benjamin B. Wolman, ed, *Handbook of Parapsychology*, Van Nostrand
    Reinhold, 1977, ISBN 0-442-29576-6
-   [Myers, David G.](http://www.davidmyers.org/esp/) *Psychology*.
    Accessed on December 9, 2004. Contains information concerning the Randi
    Foundation tests.

References {#references}
----------

[^Gracely]: Gracely, Ph.D., Ed J. (1998). "Why Extraordinary Claims Demand Extraordinary Proof". PhACT. Retrieved on 2007-07-31.
[^brnbpe]: [Britannica Online Encyclopedia](http://www.britannica.com/ebc/article-9364105), Retrieved October 7, 2007.
[^ConsciousUniverse]: *The Conscious Universe: The Scientific Truth of Psychic Phenomena* by Dean I. Radin Harper Edge, ISBN 0-06-251502-0
[^1]: Martin, D.R., & Stribic, F.P. (1938). Studies in extrasensory perception: I. An analysis of 25, 000 trials. *Journal of Parapsychology*, 2, 23-30.
[^2]: Riess, B.F. (1937). A case of high scores in card guessing at a distance. *Journal of Parapsychology*, 1, 260-263.
[^3]: Rhine, J.B. (1966). Foreword. In Pratt, J.G., Rhine, J.B., Smith, B.M., Stuart, C.E., & Greenwood, J.A. (eds.). *Extra-Sensory Perception After Sixty Years*, 2nd ed. Boston, US: Humphries.
[^4]: Beloff, J. (1986). Retrodiction. *Parapsychology Review*, *17* (1), 1-5.
[^5]: Lawrence, T. R. (1993). Gathering in the sheep and goats: A meta-analysis of forced-choice sheep-goat ESP studies, 1947-1993. *Proceedings of the Parapsychological Association 36th Annual Convention*, pp. 75-86
[^6]: Honorton, C., Ferrari, D. C., & Bem, D. J. (1998). [Extraversion and ESP performance: A meta-analysis and a new confirmation](http://www.findarticles.com/p/articles/mi_m2320/is_3_62/ai_54194994). *Journal of Parapsychology*, *62* (3), 255-276.
[^7]: Sherwood, S. J. & Roe, C. (2003). A review of dream ESP studies conducted since the Maimonides studies. *Journal of Consciousness Studies*, *10*,
85-109.
[^8]: Bem, D. J. et al.(2001). Updating the Ganzfeld database. *Journal of Parapsychology*, *65*, 207-218.
[^9]: *[Criticism and Controversy in Parapsychology - An Overview](http://www.psy.gu.se/EJP/EJP1984Bauer.pdf)* By Eberhard Bauer, Department of Psychology, University of Freiburg, in the European Journal of Parapsychology, 1984, 5, 141-166, Retrieved February 9, 2007
[^10]: [What is the state-of-the-evidence for psi?](http://www.parapsych.org/faq_file3.html#20) Retrieved January 31, 2007
[^EntangledMinds]: Entangled Minds: Extrasensory Experiences in a Quantum Reality* by Dean I. Radin, Simon & Schuster, Paraview Pocket Books, 2006 ISBN-13: 978-1416516774
[^11]: Psychological Bulletin 1994, Vol. 115, No. 1, 4-18. *Does Psi Exist? Replicable Evidence for an Anomalous Process of Information Transfer* By Daryl J. Bem and Charles Honorton
[^12]: McConnell, R.A., and Clark, T.K. (1991). "National Academy of Sciences' Opinion on Parapsychology" Journal of the American Society for Psychical Research, 85, 333-365.
[^13]: <http://findarticles.com/p/articles/mi_m2320/is_n3_v56/ai_13771782/pg_5> Retrieved February 4, 2007