**Paranormal** is an umbrella term used to
describe unusual phenomena or experiences that lack an obvious
scientific explanation.[^1] In
[[parapsychology]], it is used to describe the
potentially [[psychic]] phenomena of
[[telepathy]], [[extra-sensory perception]],
[[psychokinesis]], [[ghosts]],
and [[hauntings]]. The term is also applied to
[[UFOs]], some creatures that fall under the scope of
[[cryptozoology]], purported phenomena
surrounding the [[Bermuda Triangle]], and
other non-psychical subjects.[^2] Stories
relating to paranormal phenomena are widespread in popular
culture and
[[folklore]], but some organisations such as the
United States National Science
Foundation have stated that
mainstream science does not support paranormal
beliefs.[^3]

Paranormal research {#paranormal_research}
-------------------

Approaching paranormal phenomena from a research perspective is often
difficult because even when the phenomena are seen as
real they may be difficult to explain using existing
rules or theory. By definition, paranormal phenomena exist outside of
conventional norms. Skeptics contend that they
don't exist at all. Despite this challenge, studies on the paranormal
are periodically conducted by researchers from various
disciplines. Some researchers study just the
[[beliefs]] in paranormal phenomena regardless of
whether the phenomena actually exist.

This section deals with various approaches to the paranormal including
those scientific,
pseudoscientific, and
unscientific. Skeptics
feel that supposed scientific approaches are actually
pseudoscientific for several reasons which
are explored below.[^Beyerstein]

### Anecdotal approach {#anecdotal_approach}

An anecdotal approach to the paranormal involves the collection of
[[anecdotal evidence]] consisting of
informal accounts. Anecdotal evidence, lacking the rigor of [[empirical evidence]], is not amenable to [[scientific method|scientific
investigation]]. The anecdotal approach is
not a scientific approach to the paranormal because it leaves
verification dependent on the credibility of the party presenting the
evidence. It is also subject to such [[logical fallacy|logical fallacies]] as [[cognitive bias]], [[inductive reasoning]], lack of
[[falsifiability]], and other
fallacies that may prevent the
anecdote from having meaningful information to
impart. Nevertheless, it is a common approach to paranormal phenomena.

[[Charles Fort]] (1874 – 1932) is perhaps the
best known collector of paranormal anecdotes.
Fort is said to have compiled as many as 40,000 notes on unexplained
phenomena, though there were no doubt many more than these. These notes
came from what he called "the orthodox conventionality of Science",
which were odd events originally reported in magazines and newspapers
such as The Times and scientific
journals such as *Scientific
American*, *
Nature* and
*Science*. From this research Fort wrote
seven books, though only four survive.

Reported events that he collected include
[[teleportation]] (a term Fort is generally
credited with coining); [[poltergeist]] events,
falls of frogs, fishes, inorganic materials of an amazing range; [[crop circles]]; unaccountable noises and explosions;
[[spontaneous combustion|spontaneous fires]];
[[levitation]]; [[ball lightning]] (a term explicitly used by Fort);
[[unidentified flying objects]];
mysterious appearances and disappearances; giant wheels of light in the
oceans; and animals found outside their normal ranges (see [[phantom cat]]). He offered many reports of
[[OOPArts]], abbreviation for "out of
place" artifacts: strange items found in unlikely locations. He also is
perhaps the first person to explain strange human appearances and
disappearances by the hypothesis of [[alien abduction]], and was an early proponent of
the [[extraterrestrial hypothesis]].

Fort is considered by many as the father of modern paranormalism, which
is the study of paranormal phenomena.

The magazine Fortean Times continues Charles
Forte's approach, regularly reporting anecdotal accounts of anomalous
phenomena.

### Experimental approach {#experimental_approach}

![Participant of a Ganzfeld Experiment which proponents say may show evidence of telepathy](Files/Ganzfeldjpeg | right | 216x148 | caption)

Experimental investigation of the paranormal is largely conducted in the
multidisciplinary field of [[parapsychology]].
Although parapsychology has its roots in earlier research, it began
using the experimental approach in the 1930s under the direction of [[J. B. Rhine]] (1895 – 1980).[^EncyOccult] Rhine
popularized the now famous methodology of using card-guessing and
dice-rolling experiments in a laboratory in the hopes of finding a
statistical validation of [[extra-sensory perception]].[^EncyOccult]

In 1957, the [[Parapsychological Association]] was formed as the
preeminent society for
[[parapsychologists]]. In 1969, they became
affiliated with the [[American Association for the Advancement of Science]].
That affiliation, along with a general openness to psychic and occult
phenomena in the 1970s, led to a decade of increased parapsychological
research.[^EncyOccult] During this time, other notable organizations
were also formed, including the Academy of Parapsychology and Medicine
(1970), the Institute of Parascience (1971), the Academy of Religion and
Psychical Research, the Institute for Noetic Sciences (1973), and the
International Kirlian Research Association (1975). Each of these groups
performed experiments on paranormal subjects to varying degrees.
Parapsychological work was also conducted at the Stanford Research
Institute during this
time.[^EncyOccult]

With the increase in parapsychological investigation, there came an
increase in opposition to both the findings of parapsychologists and the
granting of any formal recognition of the field. Criticisms of the field
were focused in the founding of the Committee for the Scientific Investigation of Claims of the Paranormal (1976),
now called the [[Committee for Skeptical Inquiry]], and its
periodical, *Skeptical Inquirer*.[^EncyOccult]

Experimental research into the paranormal continues today, though it has
waned considerably since the 1970s.[^Odling-Smee] One such experiment is called the
[[Ganzfeld Experiment]]. The purpose of the Ganzfeld
Experiment, like other parapsychological experiments, is to test for
statistical anomalies that might suggest the existence of
[[psi]], a process indicating psychic
phenomena.[^psybulletin] In the Ganzfeld Experiment, a subject (receiver) is
asked to access through [[psychic]] means some target.
The target is typically a picture or video clip selected randomly from a
large pool, which is then viewed in a remote location by another subject
(sender). Ganzfeld experiments use audio and visual [[sensory deprivation]] to remove any kind of
external stimulus that may interfere with the testing or corrupt the
test by providing cues to correct targets. A 'hit' refers to a correctly
identified target. The expected hit ratio of such a trial is 1 in 4, or
25%.[^psybulletin] Deviations from this expected ratio might be seen
as evidence for [[psi]], although such
conclusions are often disputed.[^4] To date there have been no experimental results that have
gained wide acceptance in the scientific community as valid evidence of
paranormal phenomena. [^Odling-Smee]

### Participant-observer approach {#participant_observer_approach}

While parapsychologists look for
quantitative evidence of the
paranormal in laboratories, a great number of people immerse themselves
in qualitative research through
participant-observer approaches to
the paranormal. Participant-observer methodologies have overlaps with
other essentially qualitative approaches as well, including
phenomenological research that seeks
largely to describe subjects *as they are experienced*, rather than to
explain them.[^Husserl]

Participant-observation suggests that
by immersing oneself in the subject being studied, a researcher is
presumed to gain understanding of the subject. In paranormal research, a
participant-observer study might consist of a researcher visiting a
place where alleged paranormal activity is said to occur and recording
observations while there. Participation levels may vary. In studying a
supposedly [[List of allegedly haunted locations|haunted location]], for example,
the researcher may conduct a [[séance]] or participate
in other activities said to cause paranormal activity.

Criticisms of participant-observation as a data-gathering technique are
similar to criticisms of other approaches to the paranormal, but also
include an increased threat to the
[[objectivity]] of the researcher,
unsystematic gathering of data, reliance on
[[subjective]] measurement, and possible observer
effects (observation may distort the observed behavior).[^Becker]
Specific data gathering methods, such as recording
[[EMF]] readings at haunted locations have their
own criticisms beyond those attributed to the participant-observation
approach itself.

The participant-observer approach to the paranormal has gained increased
visibility and popularity through reality-based
television shows like *[Ghost
Hunters]*, and the formation of independent
[[ghost hunting]] groups which advocate
immersive research at alleged paranormal
locations. One popular
website for ghost hunting enthusiasts lists over 300 of these
organizations throughout the United States
and the United Kingdom.[^ghostgroups]

### Debunking approach {#debunking_approach}

The [[debunking]] approach is a *response* to claims of paranormal
phenomena, and consists of finding a "normal" explanation instead of a
paranormal one to account for the claims. The basis for this approach is
[[Occam's razor]], which suggests that the
simplest solution is the best one.[^5] Since standard scientific
models generally predict what can be
expected in the natural world, the debunking approach presumes that what
appears to be paranormal is necessarily a misinterpretation of natural
phenomena, rather than an actual anomalous
phenomenon. In contrast to the skeptical
position, which requires claims to be proven, the
debunking approach actively seeks to *disprove* the
claims.

The Committee for Skeptical
Inquiry is an organization that aims to publicize the skeptical
approach. It carries out investigations aimed at debunking paranormal
reports, and publishes its results in its journal the [Skeptical
Inquirer.

Former stage magician, [[James Randi]], is a well-known debunker of paranormal
claims[^6] and a prominent member of CSICOP. As a skeptic with a
background in [[illusion]], Randi feels that
the simplest explanation for those claiming paranormal abilities is
trickery, illustrated by demonstrating that the
spoon bending abilities of psychic Uri
Geller can easily be duplicated by trained
magicians.[^7] He is also
the founder of the James Randi Educational
Foundation and its
famous [[One Million Dollar Paranormal Challenge]]
offering the prize to
anyone who can demonstrate evidence of any paranormal,
[[supernatural]] or [[occult]]
power or event, under test conditions agreed to by both
parties.

An alternative to debunking is found in the field of
[[anomalistics]]. Anomalistics differs from
debunking in that debunking works on the premise that something is
either a misidentified instance of something known to science, or that
it is a hoax, while anomalistics works on the premise that something may
be either of the above, or something that can be rationalized using an
as yet unexplored avenue of science. [^hess1][^westrum1][^wescott1]

### Survey approach {#survey_approach}

While the validity of the existence of paranormal
phenomena is controversial and debated passionately by both proponents
of the paranormal and by skeptics, surveys are
useful in determining the *beliefs* of people in regards to paranormal
phenomena. These opinions, while not constituting scientific evidence
for or against, may give an indication of the mindset of a certain
portion of the population (at least among those who answered the polls).

Belief polls {#belief_polls}
------------

One such survey of the beliefs of the general United
States population regarding paranormal topics
was conducted by the Gallup
Organization in
2005.[^gallup] The survey found that 73 percent of
those polled believed in at least one of the ten paranormal items
presented in the survey.

Items included in the survey were as follows (the percentage of
respondents who indicated that they believed in the phenomenon is in
parenthesis): [[Extrasensory perception]] (41%), [[haunted houses]] (37%), [[ghosts]]
(32%), [[telepathy]] (31%),
[[clairvoyance]] (26%),
astrology (25%), communication with the dead
(21%), [[witches]] (21%),
[[reincarnation]] (20%), and
[[channeling]] spiritual entities (9%).

Only one percent of those surveyed believed in all ten items.

The items selected for the survey were chosen because they "require the
belief that humans have more than the 'normal' five senses." The poll was a follow-up a 2001 Gallup Poll that found similar results.

Another survey conducted in 2006 by researchers from
Australia's Monash
University sought to determine
what *types* of phenomena people claim to have experienced and the
effects these experiences have had on their lives. The study was
conducted as an online survey with over 2,000 respondents from around
the world participating. The results revealed that around 70% of the
respondents believe to have had an unexplained paranormal event that
changed their life, mostly in a positive way. About 70% also claimed to
have seen, heard, or been touched by an animal or person that they knew
was not there; 80% have reported having a
[[premonition]], and almost 50% stated they
recalled a previous life.[^monashresults]

Polls were conducted by Bryan Farha at Oklahoma City
University and Gary Steward of the
University of Central
Oklahoma in
2006, and compared to the results of a Gallup
poll in 2001.[^fate] They found fairly consistent results.

Other surveys by different organizations at different times have found
very similar results. A survey by Jeffrey S. Levin, associate professor
at Eastern Virginia Medical School, Norfolk found that over 2/3 of the
U.S. population reported having at least one mystical
experience.[^8][^fate]

A 1996 Gallup poll
estimated that 71% of the people in the United
States believed that the government was
covering up information about [[UFO|UFOs]]. A 2002 Roper poll
conducted for the Sci Fi channel reported that 56%
thought [[UFO|UFOs]] were real craft and 48% that
[[aliens]] had visited the
Earth.[^fate]

A 2001 National Science
Foundation survey found that 9
percent of people polled thought astrology was
very scientific, and 31 percent thought it was
somewhat scientific. About 32% of Americans
surveyed stated that some numbers were lucky, while 46% of
Europeans agreed with that claim. About 60% of all
people polled believed in some form of [[Extra-sensory perception]] and 30% thought that
"some of the unidentified flying objects that have been reported are
really space vehicles from other civilizations."[^9]

Paranormal subjects {#paranormal_subjects}
-------------------

This section explores the notable paranormal beliefs that appear in
popular culture.

### Ghosts {#ghosts}

For believers, [[ghosts]] are generally seen to be the
spirit or soul of a deceased
person.[^parasych] Alternative
theories expand on that idea and include belief in the ghosts of
deceased animals. Sometimes the term "ghost" is used synonymously with
any spirit or [[demon]][^thefreedictionary], however in popular usage the
term typically refers to a deceased person.

The belief in ghosts as souls of the departed is
closely tied to the concept of [[animism]], an ancient
belief which attributed souls to everything in nature.[^EncyOccult] As the
nineteenth-century anthropologist James
Frazer explained in his classic work, *The
Golden Bough*, souls were seen as the
creature within that animated the body. Although
the human soul was sometimes symbolically or literally depicted in
ancient cultures as a bird or other animal, it was widely held that the
soul was an exact reproduction of the body in every feature, even down
to clothing the person wore. This is depicted in artwork from various
ancient cultures, including such works as the Egyptian Book of the
Dead, which shows deceased people
in the afterlife appearing much as they did before death, including the
style of dress.

A widespread belief concerning ghosts is that they are composed of a
misty, airy, or subtle material.
Anthropologists speculate that this may also
stem from early beliefs that ghosts were the person within the person,
most noticeable in ancient cultures as a person's breath, which upon
exhaling in colder climates appears visibly as a white mist.[^EncyOccult] This
belief may have also fostered the metaphorical meaning of "breath" in
certain languages, such as the Latin
*spiritus* and the
Greek *pneuma*, which
by analogy became extended to mean the soul. In the
Bible, God is depicted as
animating Adam with a breath.

Numerous theories have been proposed by skeptics
to provide non-paranormal explanations for ghost
sightings.[^EncyOccult]
Although the evidence for ghosts is largely
anecdotal, the belief in ghosts throughout
history has remained widespread and persistent.

### UFOs {#ufos}

The possibility of [[extraterrestrial life]] is not, by itself, a paranormal
subject. Many scientists are actively engaged in the search for
unicellular life within the solar system,
carrying out studies on the surface of Mars and
examining [[meteors]] that have fallen to
Earth.[^10] Projects such as [[SETI]] are
conducting an astronomical search for radio activity
that would show evidence of intelligent life outside the solar
system.[^11] Scientific
theories of how life developed on Earth allow for
the possibility that life developed on other
planets as well. The paranormal aspect of
extraterrestrial life centers
largely around the belief in [[unidentified flying objects]] and the phenomena said
to be associated with them.

Early in the history of UFO culture, believers divided themselves into
two camps. The first held a rather conservative view of the phenomena,
interpreting it as unexplained occurrences that merited serious study.
They began calling themselves "[[ufologists]]" in the
1950s and felt that logical analysis of sighting reports would validate
the notion of extraterrestrial visitation.[^EncyOccult]

The second camp consisted of individuals who coupled ideas of
extraterrestrial visitation with beliefs from existing quasi-religious
movements. These individuals typically were enthusiasts of
[[occultism]] and the paranormal. Many had
backgrounds as active Theosophists],
Spiritualists, or were followers of other
esoteric doctrines. In contemporary times, many
of these beliefs have coalesced into New Age
spiritual movements.[^EncyOccult]

Both secular and spiritual believers describe UFOs as having abilities
beyond what is considered possible according to
aerodynamics and the laws of physics. The transitory events surrounding many
UFO sightings, like many paranormal phenomena, limits the opportunity for repeat testing required by
the [[scientific method]]. Acceptance of UFO
theories by the larger scientific
community is further hindered by the
many possible [[hoaxes]] associated with UFO culture.

Paranormal challenges {#paranormal_challenges}
---------------------

In 1922, *Scientific American* offered
two US $2,500 offers: (1) for the first authentic spirit photograph made
under test conditions, and (2) for the first psychic to produce a
"visible [[psychic]] manifestation." Harry
Houdini was a member of the investigating
committee. The first [[mediumship|medium]] to be tested was
George Valiantine, who claimed that in his presence spirits would speak
through a trumpet that floated around a darkened room. For the test,
Valiantine was placed in a room, the lights were extinguished, but
unbeknownst to him his chair had been rigged to light a signal in an
adjoining room if he ever left his seat. Because the light signals were
tripped during his performance, Valiantine did not collect the
award. The last to be examined by Scientific
American was Mina Crandon in 1924.

Since then, many individuals and groups have offered similar monetary
awards for proof of the paranormal in an observed setting. These prizes
have a combined value of over $2.4 million
dollars.

Etymology {#etymology}
---------

The word “paranormal” has been in the English since at least
1920. It
consists of two parts: para and
normal. In most definitions of the
word paranormal, it is described as anything that is beyond or contrary
to what is deemed scientifically possible.[^glossary] The
definition implies that the scientific explanation of the world around
us is the 'normal' part of the word and 'para' makes up the above,
beyond, beside, contrary, or against part of the meaning.

*Para* has a Greek and
Latin origin. Its most common meaning (the
Greek usage) is 'similar to' or 'near to', as in
paragraph. In Latin, *para* means 'above,'
against,' 'counter,' 'outside,' or 'beyond'. For example, *parapluie* in
French means 'counter-rain' - an umbrella. It can be construed, then, that the
term paranormal is derived from the Latin use of the prefix
'para', meaning 'against, counter, outside or beyond
the norm.'

See also {#see_also}
--------

**Paranormal:** [[Cryptozoology]],
[[Forteana]], [[Ghosts]], [[List of haunted locations|Haunted locations]],
[[Occult]], [[Paranormal explanations for UFOs]],
[[Parapsychology]],
[[Psychics]],
[[Supernatural]], [[UFOs]],
[[Unidentified submerged object|USO]]

**Authors:** [[Charles Fort]], [[Arthur C Clark]], [[J. B. Rhine]], [[Carl Sagan]]

**[[Skepticism]]:** [[Debunking]], [[Ghost Hunters]], [[Hoaxes]], [[James Randi]], [[List of prizes for evidence of the paranormal|Prizes offered for paranormal proof]]

**Science:** [[Anomaly]], [[Scientific method]]

References {#references}
----------

[^1]: [Paranormal](http://www.thefreedictionary.com/paranormal) in *TheFreeDictionary*, Accessed February 3, 2008
[^2]: [What is PSI? What Isn't?](http://www.parapsych.org/what_is_psi_varvoglis.htm), [[Parapsychological Association]], accessed August
01, 2006
[^3]: What is something is real? Do we call it "fact" or "theory". [Belief in the Paranormal or Pseudoscience](http://www.nsf.gov/statistics/seind00/access/c8/c8s5.htm)
[^Beyerstein]: Beyerstein, B. L. (1996). [Distinguishing Science from Pseudoscience](http://www.sfu.ca/~beyerste/research/articles/02SciencevsPseudoscience.pdf)
[^EncyOccult]: Encyclopedia of Occultism & Parapsychology edited by J. Gordon Melton Gale Research, ISBN 0-8103-5487-X
[^Odling-Smee]: Odling-Smee, L. (2007). [The Lab That Asked The Wrong Questions](http://intl.emboj.org/nature/journal/v446/n7131/full/446010a.html).
Nature, February 2007.
[^psybulletin]: Psychological Bulletin 1994, Vol. 115, No. 1, 4-18. *Does Psi Exist? Replicable Evidence for an Anomalous Process of Information Transfer* By Daryl J. Bem and Charles Honorton
[^4]: [The Skeptic's Dictionary: Psi Assumption](http://skepdic.com/psiassumption.html), Robert Todd Carroll, accessed January 3, 2006
[^Husserl]: Logical Investigations Husserl, E. 1970 Humanities Press
[^Becker]: Problem of inference and proof in participant observation : Problem of inference and proof in participant-observation, Reprint edition. Becker, Howard S. 1993 Irvington Pub
[^ghostgroups]: [Paranormal Groups](http://www.ghostvillage.com/links/links_groups.shtml), GhostVillage.com, accessed December 14, 2006
[^5]: [Three skeptics' debate tools examined](http://findarticles.com/p/articles/mi_m2843/is_1_26/ai_80924583/pg_1), accessed July 1, 2007
[^6]: [JREF Commentary, February 18, 2005](http://www.randi.org/jr/021805a.html), accessed July 1, 2007
[^7]: Interview with James Randi in NOVA episode, "Secrets of the Psychics"
[^hess1]: Hess David J. (1997) "Science Studies: an advanced introduction" New York University Press, ISBN 0814735649
[^westrum1]: R. Westrum, Truzzi Marcello (1978) "Anomalies: A Bibliographic Introduction with Some Cautionary Remarks", Zetetic Scholar 2, p. 69-90
[^wescott1]: Wescott, Robert W. (1973) "Anomalistics: The Outline of an Emerging Field of Investigation" Research Division, New Jersey Department of Education
[^gallup]: [Gallup poll shows that Americans' belief in the paranormal persists](http://www.findarticles.com/p/articles/mi_m2843/is_5_29/ai_n15400020),
Skeptical Inquirer, accessed October 28, 2006
[^monashresults]: ['Spooky survey' gets big response](http://www.abc.net.au/science/news/stories/2006/1791144.htm), ABC Science Online, 17 November 2006
[^fate]: *Smart People See Ghosts*, Brad Steiger, Fate Magazine, April 2006 Issue, p. 52-56; the unusual thing found by Farha and Steward was that belief in the supernatural increased with education level, contrary to many other surveys. However, that aspect of their study is not being used here.
[^8]: USA Today, January 12, 1994
[^9]: [*Science and Technology: Public Attitudes and Understanding-Public Knowledge About S&T*, Chapter 7 of Science and Engineering Indicators 2004, National Science Board, National Science Foundation](http://www.nsf.gov/statistics/seind04/c7/c7s2.htm#fn21)
[^parasych]: [Parapsychological Association, glossary of key words frequently used in parapsychology](http://www.parapsych.org/glossary_e_k.html#g), Retrieved December 13 2006
[^thefreedictionary]: [The Free Dictionary](http://www.thefreedictionary.com/ghost). Retrieved December 13 2006
[^10]: [NASA Scientists To Discuss Search For Extraterrestrial Life](http://www.spacedaily.com/news/life-03zzt.html), Space Daily, Dec 11, 2003
[^11]: [How SETI Works](http://www.howstuffworks.com/seti.htm), HowStuffWorks.com, Accessed July 4, 2007
[^glossary]: [Glossary, The Journal of Parapsychology](http://www.findarticles.com/p/articles/mi_m2320/is_1_68/ai_n13699208/pg_4),
[Parapsychological Association](Parapsychological_Association "wikilink"), accessed August 05, 2006