**Parapsychology** is a discipline that seeks to investigate the
existence and causes of [[psychic]] abilities and
life after death using the
[[scientific method]]. Laboratory and field
research is conducted by privately funded laboratories and some
universities around the world,[^faqfile1]
although there are fewer universities actively sponsoring
parapsychological research today than in years past. Such research is
usually published in parapsychological publications, and some articles
have appeared in more mainstream journals. Experiments have included the
use of random number generators
to test for evidence of [[precognition]] and
[[psychokinesis]] with both human and animal
subjects,
[[sensory-deprivation]] and [[Ganzfeld experiments]] to test for extrasensory
perception, and research trials conducted under contract to the United
States government to investigate whether [[remote viewing]] would provide useful intelligence
information.

The position of many parapsychologists is that the existence of some
forms of psi such as psychokinesis and ESP has good supporting
evidence.[^faqfile3] The greater scientific
community has not accepted that there
exists evidence for psychic abilities.[^CaliBoard][^faqfile1] In 1988 the U.S.
National Academy of
Sciences produced a
report that concluded that there is "no scientific justification from
research conducted over a period of 130 years for the existence of
parapsychological phenomena."[^NAS] Some
science educators and scientists have called the subject
pseudoscience.[^Carroll1]
Psychologists such as Ray Hyman, Stanley
Krippner, and James
Alcock have criticized both the methods used
and the results obtained in parapsychology, stating that methodological
flaws may explain any apparent experimental successes.[^prtr]

Terminology {#terminology}
-----------

The term *parapsychology* was coined in or before 1889 by psychologist
Max Dessoir. It was adopted by [[J.B. Rhine]] in the 1930s as a replacement for the term
*psychical research*, to indicate a significant shift toward laboratory
methodologies in their work.[^Melton] The term
originates from the meaning "alongside", and
*psychology*. Parapsychologists call the
psychic phenomena that they search for
*[[psi]]*, a term intended to be
descriptive without implying a mechanism.

History {#history}
-------

### Early psychical research {#early_psychical_research}

The [[Society for Psychical Research]] (SPR) was founded
in London in 1882. The formation of the SPR was the first systematic
effort to organize scientists and scholars for a critical and sustained
investigation of paranormal phenomena. The early membership of the SPR
included philosophers, scholars, scientists, educators and politicians,
such as Henry Sidgwick, Arthur
Balfour, William
Crookes, Rufus Osgood
Mason and Charles
Richet.[^Beloff]

The SPR classified its subjects of study into several areas:
[[telepathy]], [[hypnotism]],
[[Reichenbach's phenomena]],
[[apparitions]],
[[hauntings]], and the physical aspects of
[[Spiritualism]] such as
table-tilting and the appearance of matter from unknown sources,
otherwise known as
[[materialization]]. One of the
first collaborative efforts of the SPR was its *Census of
[[Hallucinations]]*, which researched apparitional experiences and
hallucinations. The
census was the Society's first attempt at a statistical evaluation of
paranormal phenomena, and the resulting publication in 1886, *Phantasms
of the Living* is still widely referenced in parapsychological
literature today. The SPR became the model for similar societies in
other European countries and the United States during the late 19th
century. Largely due to the support of psychologist William
James, the [[American Society for Psychical Research]] (ASPR)
opened its doors in New York City in
1885.[^Berger]

Today, the SPR and ASPR continue the investigation of [[psi]]
phenomena. The SPR's purpose is stated
in every issue of its *Journal* - being "to examine without
prejudice or prepossession and in a scientific spirit those faculties of
man, real or supposed, which appear to be inexplicable on any generally
recognized hypothesis."

### Rhine era {#rhine_era}

In 1911, Stanford University became
the first academic institution in the United
States to study [[extrasensory perception]] (ESP)
and [[psychokinesis]] (PK) in a laboratory
setting. The effort was headed by psychologist John Edgar Coover. In
1930, Duke University became the second
major U.S. academic institution to engage in the critical study of ESP
and psychokinesis in the laboratory. Under the guidance of psychologist
William McDougall, and
with the help of others in the department—including psychologists [[Karl Zener]], [[J. B. Rhine], and Louisa E. Rhine—laboratory ESP
experiments using volunteer subjects from the undergraduate student body
began. As opposed to the approaches of psychical research, which
generally sought qualitative evidence
for paranormal phenomena, the experiments at Duke University proffered a
quantitative,
statistical approach using
[[Zener cards|cards]] and dice. As a consequence of the ESP
experiments at Duke, standard laboratory procedures for the testing of
ESP developed and came to be adopted by interested researchers
throughout the world.[^Berger]

The publication of J.B. Rhine's book, *New Frontiers of the Mind* (1937)
brought the laboratory's findings to the general public. In his book,
Rhine popularized the word "parapsychology," which psychologist Max
Dessoir had coined over 40 years earlier, to
describe the research conducted at Duke. Rhine also founded an
autonomous Parapsychology Laboratory within Duke and started the
*Journal of Parapsychology*,
which he co-edited with McDougall.[^Berger]

The parapsychology experiments at Duke evoked much criticism from
academic psychologists who challenged the concepts and evidence of ESP.
Rhine and his colleagues attempted to address these criticisms through
new experiments, articles, and books, and summarized the state of the
criticism along with their responses in the book *Extra-Sensory
Perception After Sixty Years*.[^ESP60]

The administration of Duke grew less sympathetic to parapsychology, and
after Rhine's retirement in 1965 parapsychological links with the
university were broken. Rhine later established the Foundation for
Research on the Nature of Man (FRNM) and the Institute for
Parapsychology as a successor to the Duke laboratory.[^Berger] In 1995, the centenary of Rhine's birth, the FRNM was
renamed the Rhine Research Center. Today, the Rhine Research Center is a
parapsychology research unit, stating that it "aims to improve the human
condition by creating a scientific understanding of those abilities and
sensitivities that appear to transcend the ordinary limits of space and
time."

### Establishment of the Parapsychological Association {#establishment_of_the_parapsychological_association}

The [[Parapsychological Association]] (PA) was created
in Durham, North Carolina, on June
19, 1957. Its formation was proposed by J. B. Rhine at a workshop on
parapsychology which was held at the Parapsychology Laboratory of Duke
University. Rhine proposed that the group form itself into the nucleus
of an international professional society in parapsychology. The aim of
the organization, as stated in its Constitution, became "to advance
parapsychology as a science, to disseminate knowledge of the field, and
to integrate the findings with those of other branches of
science".

Under the direction of anthropologist Margaret
Mead, the Parapsychological Association took
a large step in advancing the field of parapsychology in 1969 when it
became affiliated with the [[American Association for the Advancement of Science]]
(AAAS), the largest general scientific society in the
world. In 1979, physicist John A.
Wheeler argued that parapsychology is
pseudoscientific, and that the affiliation of the PA to the AAAS needed
to be reconsidered.[^Wheeler] His challenge to
parapsychology's AAAS affiliation was unsuccessful.[^Wheeler]
Today, the PA consists of about three hundred full, associate, and
affiliated members worldwide and maintains its affiliation with the
AAAS.[^Harvey] The annual AAAS convention
provides a forum where parapsychologists can present their research to
scientists from other fields and advance parapsychology in the context
of the AAAS's lobbying on national science policy.[^Harvey]

### Decade of increased research (1970s) {#decade_of_increased_research_1970s}

The affiliation of the Parapsychological Association (PA) with the
American Association for the Advancement of Science, along with a
general openness to psychic and [[occult]] phenomena in
the 1970s, led to a decade of increased parapsychological research.
During this period, other notable organizations were also formed,
including the Academy of Parapsychology and Medicine (1970), the
Institute of Parascience (1971), the Academy of Religion and Psychical
Research, the Institute of Noetic
Sciences (1973), the
International Kirlian Research Association (1975), and the Princeton
Engineering Anomalies Research
Laboratory
(1979). Parapsychological work was also conducted at the Stanford
Research Institute (SRI) during
this time.[^Melton]

The scope of parapsychology expanded during these years. Psychiatrist
Ian Stevenson conducted much of his
controversial research into [[reincarnation]]
during the 1970s. Psychologist Thelma Moss
devoted time to the study of [Kirlian photography]] at
UCLA's parapsychology laboratory. The influx of
spiritual teachers from Asia, and their claims of abilities produced by
[[meditation]], led to research on [[altered states of consciousness]]. American
Society for Psychical Research Director of Research, Karlis Osis,
conducted experiments in out of body, and astral beaconing. Physicist
Russell Targ coined the term [[remote viewing]] for use in some of his work at
SRI in 1974.[^Melton]

During this period, academics outside parapsychology also appeared to
have a general optimism towards this research. In 1979, a survey of more
than 1,100 college professors in the United States found that only 2% of
psychologists expressed the belief that
[[extrasensory perception]] was an impossibility. A far greater number, 34%,
indicated that they believed ESP was either an established fact or a
likely possibility. The percentage was even higher in other areas of
study: 55% of natural scientists, 66% of
social scientists (excluding
psychologists), and 77% of academics in the arts,
humanities, and
education believed that ESP research was
worthwhile.

The surge in paranormal research continued throughout the 1970s and into
the 1980s. By the end of the 1980s, the Parapsychological Association
reported members working in more than 30 countries. Additionally,
research not affiliated with the PA was being carried out in Eastern
Europe and the former Soviet
Union.[^Melton]

### Parapsychology today {#parapsychology_today}

Since the 1970s, contemporary parapsychological research has waned
considerably in the United States.[^Smee] Early
research was considered inconclusive, and parapsychologists were faced
with strong opposition from their academic colleagues.[^Melton] Some effects thought to be paranormal, for example,
the effects of [[Kirlian photography]], disappeared
under more stringent controls, leaving those avenues of research at
dead-ends.[^Melton] Many university laboratories in the
United States have closed, citing a lack of acceptance by mainstream
science as the reason, leaving the bulk of parapsychology confined to
private institutions funded by private sources.[^Melton] After 28 years of research, Princeton Engineering
Anomalies Research
Laboratory
(PEAR) retired their laboratory in 2007.[^Smee]

Two universities in the United States still have academic parapsychology
laboratories: the Division of Perceptual Studies, a unit at the
University of Virginia's Department
of Psychiatric Medicine, studies the possibility of survival of
consciousness after bodily death; the University of
Arizona's Veritas Laboratory conducts
laboratory investigations of [[mediums]]. Several
private institutions, including the Institute of Noetic Sciences,
conduct and promote parapsychological research. Britain
leads parapsychological study in Europe, with
privately funded laboratories at the universities of
Edinburgh,
Northampton, and Liverpool
Hope, among others.[^Smee]

Parapsychological research has also been augmented by other
sub-disciplines of psychology. These related fields include
transpersonal psychology, which
studies transcendent or spiritual aspects of the human mind, and
anomalistic psychology, which examines paranormal beliefs and subjective
anomalous experiences in traditional psychological terms.[^cardenza][^Smee]

Research {#research}
--------

### Scope {#scope}

Parapsychologists study a number of ostensible paranormal phenomena,
including but not limited to:

-   **[[Telepathy]]**: Transfer of information on
    thoughts or feelings between individuals by means other than the
    five classical senses.
-   **[[Precognition]]**: Perception of
    information about future places or events before they occur.
-   **[[Clairvoyance]]**: Obtaining information
    about places or events at remote locations, by means unknown to
    current science.
-   **[[Psychokinesis]]**: The ability of the
    mind to influence matter, time, space, or energy by means unknown to
    current science.
-   **[[Reincarnation]]**: The rebirth of a soul
    or other non-physical aspect of human
    consciousness in a new physical body
    after death.
-   **[[Hauntings]]**: Phenomena often attributed to
    ghosts and encountered in places a deceased individual is thought to
    have frequented, or in association with the person's former
    belongings.

The definitions for the terms above may not reflect their
mainstream usage, nor the opinions of all
parapsychologists and their critics. Many critics, for example, feel
that parapsychologists are engaged in the study of phenomena that
disappear under stringent experimental conditions and are thus normal
processes.

According to the Parapsychological Association, parapsychologists do not
study all paranormal phenomena, nor are they concerned with
astrology, [[UFOs]],
[[Bigfoot]], paganism,
vampires, [[alchemy]], or
[[witchcraft]].[^faqfile1]

### Methodology {#methodology}

Parapsychologists employ a variety of approaches during the study of
apparent paranormal phenomena. These methods include qualitative
approaches used in traditional psychology, but also quantitative
empirical methodologies. Their more
controversial studies involve the use of
meta-analysis in examining the 
statistical evidence for psi.[^Smee]

### Experimental research {#experimental_research}

#### Ganzfeld {#ganzfeld}

The [[Ganzfeld_experiment|ganzfeld]] (German for "whole
field") is a technique used to test individuals for telepathy. The
technique was developed to quickly quiet mental "noise" by providing a
mild, unpatterned sensory field to mask the visual
and auditory environment. Isolating the
visual sense is usually achieved by creating a soft red glow which is
diffused through half ping-pong balls placed over the recipient's eyes.
The auditory sense is usually blocked by playing white noise, static, or
similar sounds to the recipient. The subject is also seated in a
reclined, comfortable position to minimize the sense of touch.

In the typical ganzfeld experiment, a "sender" and "receiver" are
isolated.[^HymanGanzfeld] The receiver is put into the ganzfeld state, and the
sender is shown a video clip or still picture and asked to mentally send
that image to the receiver. The receiver, while in the ganzfeld, is
asked to continuously speak aloud all mental processes, including
images, thoughts, and feelings. At the end of the sending period,
typically about 20 to 40 minutes in length, the receiver is taken out of
the ganzfeld and shown four images or videos, one of which is the true
target and three of which are non-target decoys. The receiver attempts
to select the true target, using perceptions experienced during the
ganzfeld state as clues to what the mentally "sent" image might have
been.

According to parapsychologists such as Dean
Radin, Charles
Honorton, and Daryl
Bem, the results of ganzfeld
experiments—collectively gathered from over 3,000 individual sessions
conducted by about two dozen investigators worldwide—indicate that, on
average, the target image is selected by the receiver more often than
would be expected by chance alone.[^Radnin97]
Because these meta analyses of ganzfeld results are said to be 
statistically significant, they
have sparked debates within mainstream academic psychology journals over
how to properly interpret the data.[^Honorton]

#### Remote viewing {#remote_viewing}

Remote viewing experiments test the ability to gather information on a
remote target consisting of an object, place, or person that is hidden
from the physical perception of the viewer and typically separated from
the viewer at some distance. In one type of remote viewing experiment, a
pool of several hundred photographs are created. One of these is
randomly selected by a third party to be the target. It is then set
aside in a remote location. The remote viewer attempts to sketch or
otherwise describe that remote target photo. This procedure is repeated
for a number of different targets. Many ways of analytically evaluating
the results of this sort of experiment have been developed. One common
method is to take the group of seven target photos and responses,
randomly shuffle the targets and responses, and then ask independent
judges to rank or match the correct targets with the participant's
actual responses. This method assumes that if there were an anomalous
transfer of information, the responses should correspond more closely to
the correct targets than to the mismatched targets.[^Dunne]

Several hundred such trials have been conducted by investigators over
the past 25 years, including by the Princeton Engineering Anomalies
Research
Laboratory
(PEAR) and by scientists at SRI
International and
Science Applications International Corporation (SAIC), under
contract by the U.S. government. The
cumulative data was interpreted by Professor of Aerospace Science
Robert G. Jahn and psychologist Brenda
Dunne at PEAR as indicating that information about remote photos, actual
scenes, and events can be perceived beyond chance expectation.[^Dunne]

#### Psychokinesis on random number generators {#psychokinesis_on_random_number_generators}

The advent of powerful and inexpensive electronic and computer
technologies has allowed the development of fully automated experiments
studying possible interactions between mind and
matter. In the most common experiment
of this type, a true random number
generator (RNG), based on
electronic or radioactive noise, produces a
data stream that is recorded and analyzed by computer
software. A subject attempts to mentally alter
the distribution of the random numbers, usually in an experimental
design that is functionally equivalent to getting more "heads" than
"tails" while flipping a coin. In the RNG experiment, design flexibility
can be combined with rigorous controls, while collecting a large amount
of data in very short period of time. This technique has been used both
to test individuals for psychokinesis and to test the possible influence
on RNGs of large groups of people.[^Dunne85]

Major meta-analyses of the RNG database have been published every few
years since appearing in the journal *Foundations of
Physics* in 1986.[^Dunne85] PEAR founder Robert G.
Jahn and his colleague Brenda Dunne say that
the effect size in all cases was found to be very small, but consistent
across time and experimental designs, resulting in an overall
statistical significance. The
most recent meta-analysis was published in *Psychological
Bulletin*, along with several
critical commentaries.[^pmid16822162][^pmid16822164] This was composed of 380 studies,
with the authors reporting an overall positive effect size that was
statistically significant but very small, within the margin that could
be explained by publication bias.

#### Direct mental interactions with living systems {#direct_mental_interactions_with_living_systems}

Formerly called bio-PK, "direct mental interactions with living systems"
(DMILS) studies the effects of one person's intentions on a distant
person's psychophysiological
state.[^pmid15142304] One type of DMILS experiment
looks at the commonly reported "feeling of being stared at." The
"starer" and the "staree" are isolated in different locations, and the
starer is periodically asked to simply gaze at the staree via closed
circuit video links. Meanwhile, the staree's nervous system activity is
automatically and continuously monitored.

Parapsychologists have interpreted the cumulative data on this and
similar DMILS experiments to suggest that one person's attention
directed towards a remote, isolated person can significantly activate or
calm that person's nervous system. In a
meta-analysis of these experiments published in the *British Journal of
Psychology* in 2004, researchers found that there was a small but
significant overall DMILS effect. However, the study also found that
when a small number of the highest-quality studies from one laboratory
were analyzed, the effect size was not significant. The authors
concluded that although the existence of some anomaly related to distant
intentions cannot be ruled out, there was also a shortage of independent
replications and theoretical concepts.[^pmid15142304]

### Near death experiences {#near_death_experiences}

A [[near-death experience]] (NDE) is an
experience reported by a person who nearly died, or who experienced
clinical death and then revived. NDEs
include one or more of the following experiences: a sense of being dead;
an [[out-of-body experience]]; a
sensation of floating above one's body and seeing the surrounding area;
a sense of overwhelming love and peace; a sensation of moving upwards
through a tunnel or narrow passageway; meeting deceased relatives or
spiritual figures; encountering a being of light, or a light;
experiencing a life review; reaching a border
or boundary; and a feeling of being returned to the body, often
accompanied by reluctance.[^Mauro]

Interest in the NDE was originally spurred by the research of
psychiatrists Elisabeth Kübler-Ross,
George Ritchie, and Raymond Moody Jr. In
1998, Moody was appointed chair in "consciousness studies" at the
University of Nevada, Las
Vegas. The [[International Association for Near-death Studies]]
(IANDS) was founded in 1978 to meet the needs of early researchers and
experiencers within this field of research. Later researchers, such as
psychiatrist Bruce Greyson, psychologist
Kenneth Ring, and cardiologist Michael Sabom,
introduced the study of near-death experiences to the academic
setting.[^Mauro]

Some researchers, including Dr. Rick
Strassman, believe that near death
experiences may be related to the chemical DMT's
(Dimethyltryptamine) release from the pineal gland. The chemical is
released naturally during sleep, is thought to have an effect on
dream content, and is used as a recreational drug.
Strassman sees the chemical as a mediator for hyperdimensional
experiences, and points out that experiences with the drug are
comparable to NDE's.[^1]

### Anomalous psychology {#anomalous_psychology}

A number of studies conducted in the American,
European, and
Australasian continents have found that a
majority of people surveyed report having had experiences that could be
interpreted as [[telepathy]], [[precognition]], and
similar phenomena. Variables that have been associated with reports of
psi-phenomena include belief in the reality of [[psi]]; the tendency to have
[[hypnotic]],
dissociative, and other alterations of
consciousness; and, less reliably so,
neuroticism,
extraversion, and openness to experience.
Although psi-related experiences can occur in the context of such
psychopathologies as schizotypal personality, dissociative, and other
disorders, most individuals who endorse a belief in psi are
well-adjusted, lack serious pathology, and are
not intellectually deficient or lacking critical abilities.[^cardenza]

Criticism {#criticism}
---------

Scientists
who are critical of parapsychology begin with the assertion that
extraordinary claims demand extraordinary evidence. Proponents of
hypotheses that contradict centuries of scientific research must provide
extraordinary evidence if their hypotheses are to be taken
seriously.[^Gracely] Many analysts of
parapsychology hold that the entire body of evidence to date is of poor
quality and not adequately controlled. In their view, the entire field
of parapsychology has produced no conclusive results whatsoever. They
cite instances of fraud, flawed studies, a psychological need for
mysticism, and [[cognitive bias|cognitive biases]] (such as [[clustering illusion]], availability
error, [[confirmation bias]], illusion of
control, and the [[bias blind spot]])[^Moulton]
as ways to explain parapsychological results.
Skeptics have also contended that people's desire to believe in
paranormal phenomena causes them to discount strong evidence that it
does not exist.

The reality of parapsychological phenomena and the scientific validity
of parapsychological research is disputed by independent evaluators and
researchers. In 1988, the U.S. National Academy of
Sciences gave a report on
the subject that concluded that "no scientific justification from
research conducted over a period of 130 years for the existence of
parapsychological phenomena."[^NAS] In the same report,
however, they also recommended monitoring some parapsychological
research, such as psychokinesis on random number generators and Ganzfeld
effects, for possible future studies.[^NAS] The studies
at the PEAR
lab,
recommended for monitoring by the report, have since concluded. These
studies likewise failed to elicit a positive response by the scientific
community despite numerous trials.[^Smee] A 2008 study
using fMRI showed no detectable psi effect.[^Moulton]

Additionally, the methods of parapsychologists are regarded by some
critics, including those who wrote the science standards for the
California State Board of
Education,[^CaliBoard] to be
pseudoscientific.[^Beyerstein] Some of the more specific criticisms
state that parapsychology does not have a clearly defined subject
matter, an easily repeatable experiment that can demonstrate a psi
effect on demand, nor an underlying theory to explain the paranormal
transfer of information.[^Hyman] James E. Alcock,
Professor of Psychology at York
University, said that few of
parapsychology's experimental results have prompted interdisciplinary
research with more mainstream sciences such as
physics or biology. Alcock
states that parapsychology remains an isolated science to such an extent
that its very legitimacy is questionable,[^Alcock81] and as a whole is not justified in being
labeled "scientific".[^Alcock98]

### Fraud {#fraud}

There have been instances of [[fraud]] in the history of
parapsychology research. The Soal-Goldney experiments of 1941-43
(suggesting precognitive ability in subjects) were long regarded as some
of the best in the field because they relied upon independent checking
and witnesses to prevent fraud. However, many years later, suspicions of
fraud were confirmed when statistical evidence, uncovered and published
by other parapsychologists in the field, indicated that Dr. Soal had
cheated by altering the raw data.[^Alcock81][^Haskell][^Markwick]

Walter J. Levy, director of the Institute for Parapsychology, reported
on a series of successful ESP experiments involving computer-controlled
manipulation of non-human subjects, including eggs and rats. His
experiments showed very high positive results. Because the subjects were
non-human, and because the experimental environment was mostly
automated, his successful experiments avoided criticism concerning
experimenter effects, and
removed the question of the subject's belief as an influence on the
outcome. However, Levy's fellow researchers
became suspicious about his methods. They found that Levy interfered
with data-recording equipment, manually creating fraudulent strings of
positive results. Rhine fired Levy and reported the fraud in a number of
articles.

Many [[spiritualist]]
[[mediums]] used fraud, and some were exposed by
early psychical researchers such as Richard
Hodgson and Harry
Price. In the 1920s,
magician and escapologist Harry
Houdini said that researchers and observers
had not created experimental procedures which absolutely preclude
fraud.[^Houdini] In 1979, magician and
debunker James Randi
perpetrated a hoax, now referred to as [[Project Alpha]]. Randi recruited two young magicians
and sent them under cover to Washington
University's McDonnell Laboratory
with the specific aim of exposing poor experimental methods and the
credulity thought to be common in parapsychology. The McDonnell
laboratory did not make any formal statements or publications suggesting
that the effects demonstrated by the two magicians were genuine.
However, Randi has stated that both of his recruits deceived
experimenters over a period of three years with demonstrations of
supposedly psychic abilities: blowing electric fuses sealed in a box,
causing a lightweight paper rotor perched atop a needle-point to turn
inside a bell jar, bending metal spoons sealed in a glass bottle,
etc.[^2][^3]
Such methodological failures have been cited as evidence that most, if
not all, extraordinary results in parapsychology derive from error or
fraud.

### Criticism of experimental results {#criticism_of_experimental_results}

Although some critical analysts feel that parapsychological study is
scientific, they are not satisfied with its
experimental results.[^Alcock03][^Hyman] Skeptical reviewers contend that apparently
successful experimental results in psi research are more likely due to
sloppy procedures, poorly trained researchers, or methodological flaws
than to genuine psi effects.[^Akers]
For example, the data from the PEAR laboratory has been criticized by
researchers such as statistics professor Jessica
Utts and psychologist Ray
Hyman. Utts has stated that these experiments
suffered numerous problems with regard to randomization, statistical
baselines and the application of statistical models, and concluded that
the significance values quoted in the experiments were meaningless due
to defects in experimental and statistical procedures of the
studies.

Because psi is a negatively defined concept, a typical measure of the
evidence for such phenomena in parapsychological experiments is
statistical deviation from chance expectation. However, critics point
out that statistical deviation from chance is, strictly speaking, only
evidence of a statistical anomaly, or that some unknown variable was
causing the deviation from chance. Hyman contends that even if
experiments could be made to reproduce the findings of certain
parapsychological studies under specific conditions, this would be a far
cry from concluding that psychic functioning has been
demonstrated.[^Hyman33] It has also been
stated that assuming psi exists is affirming the
consequent or begging the
question. Reasoning that (1) if a
person is psychic, then that individual will do better than chance in
experiments, and (2) since that person does better than chance, then,
(3) that person must be psychic, would be considered the fallacy of
affirming the consequent.[^Carroll2]

### Selection bias and meta-analysis {#selection_bias_and_meta_analysis}

Selective reporting has been offered by
critics as an explanation for the positive results reported by
parapsychologists. Selective reporting is sometimes referred to as a
"file drawer" problem, which arises when only positive study results are
made public, while studies with negative or null results are not made
public.[^pmid16822164] Selective reporting has a
compounded effect on meta-analysis, which is
a statistical technique that aggregates the results of many studies in
order to generate sufficient statistical
power to demonstrate a result that the
individual studies themselves could not demonstrate at a statistically
significant level. For example, a
recent meta-analysis combined 380 studies on
[[psychokinesis]],[^pmid16822162] including data from the PEAR
lab. It
concluded that, although there is a statistically significant overall
effect, it is not consistent and relatively few negative studies would
cancel it out. Consequently, biased
publication of positive results could be
the cause.[^Smee]

The popularity of meta-analysis in parapsychology has been criticized by
numerous researchers, and is often seen as troublesome even within
parapsychology itself. Critics have said that
parapsychologists misuse meta-analysis to create the incorrect
impression that statistically significant results have been obtained
which indicate the existence of psi phenomena.[^Stenger]

Researcher J. E. Kennedy has argued that concerns over the use of
meta-analysis in science and medicine apply as well to problems present
in parapsychological meta-analysis. As a post-hoc
analysis, critics emphasize the
opportunity the method presents to produce biased outcomes via the
selection of cases chosen for study, methods employed, and other key
criteria. Critics claim analogous problems with meta-analysis have been
documented in medicine, where it has been shown different investigators
performing meta-analyses of the same set of studies have reached
contradictory conclusions.

Organizations and publications {#organizations_and_publications}
------------------------------

The lack of acceptance by mainstream science has led to a decline in
academic ties to parapsychological research.[^Smee]
Still, there are some university laboratories that continue to conduct
parapsychological experiments. Among these are the Koestler
Parapsychology Unit at the
University of
Edinburgh,
the Parapsychology Research Group at Liverpool Hope
University,
the VERITAS Research Program at the University of
Arizona, the
Consciousness and Transpersonal Psychology Research Unit of Liverpool
John Moores
University,
the Center for the Study of Anomalous Psychological Processes at the
University of
Northampton,
and the Anomalistic Psychology Research Unit at Goldsmiths University
of London]. The
Princeton Engineering Anomalies
Research, a
well-known laboratory that conducted
[[psychokinesis]] experiments, closed in
February 2007.

Research organizations include the [[Parapsychological Association]], the [[Society for Psychical Research]],
publisher of the *Journal of Society for Psychical
Research*; the [[American Society for Psychical Research]], publisher of the *Journal of the American Society for
Psychical Research*; the Rhine Research Center
and Institute for Parapsychology, publisher of the *Journal of
Parapsychology*; the Parapsychology Foundation,
publisher of the *International Journal of
Parapsychology*; and the Australian Institute of
Parapsychological Research, publisher of the *Australian Journal of
Parapsychology*. The *European Journal of
Parapsychology* is independently published.

Organizations that encourage a critical examination of parapsychology
and parapsychological research include the [[Committee for Skeptical Inquiry]], publisher of the
*Skeptical Inquirer*; and
the James Randi Educational
Foundation, founded by
magician and
skeptic James
Randi.


Further reading {#further_reading}
---------------

-   Holzer, Hans Ph.D. Parapsychologist, Author: [*The Supernatural: Explaining the Unexplained*](http://www.bookideas.com/reviews/index.cfm?fuseaction=displayReview&id=1649) Publisher: Franklin Lakes, NJ: New Page Books, 2003.

External links {#external_links}
--------------

-   [Parapsychology FAQ](http://www.parapsych.org/faq_file1.html)
    Frequently asked questions, by the [Parapsychological
    Association](Parapsychological_Association "wikilink"), a
    professional organization of scientists and scholars engaged in the
    study of psychic phenomena, affiliated with the [American
    Association for the Advancement of
    Science](American_Association_for_the_Advancement_of_Science "wikilink")
    in 1969.

-   [FindArticles.com Index](http://findarticles.com/p/search?qt=parapsychology) Large
    number of articles about parapsychology, from publications such as
    the *[Journal of
    Parapsychology](Journal_of_Parapsychology "wikilink")* and the
    *[Skeptical Inquirer](Skeptical_Inquirer "wikilink")*.

-   [Committee for Skeptical Inquiry](http://csicop.org) Organization
    formed in 1976 to promote scientific
    skepticism and encourage the
    critical investigation of paranormal claims and parapsychology.

References {#references}
----------

[^faqfile1]: <http://www.parapsych.org/faq_file1.html> FAQ of the Parapsychological Association
[^faqfile3]: <http://www.parapsych.org/faq_file3.html#20> FAQ of the Parapsychological Association
[^CaliBoard]: (1990) Science Framework for California Public Schools. California State Board of Education.
[^Radnin97]: Radin, Dean (1997). The Conscious Universe: The scientific Truth of Psychic Phenomena. Harper, San Francisco. ISBN 0062515020.
[^Carroll1]: Sean M.Carroll describes it as such on his blog [*Cosmic Variance*](http://cosmicvariance.com/2008/02/14/american-association-for-the-advancement-of-pseudoscience/)
[^ESP60]: Rhine, J.B. (1966). Foreword. In Pratt, J.G., Rhine, J.B., Smith, B.M., Stuart, C.E., & Greenwood, J.A. (eds.). Extra-Sensory Perception After Sixty Years, 2nd ed. Boston, US: Humphries.
[^HymanGanzfeld]: The Ganzfeld Psi Experiments: A Critical Appraisal, Ray Hyman, Journal of Parapsychology 49, 1985.
[^1]: Rick Strassman, ["DMT: The Spirit Molecule"](http://www.rickstrassman.com/pages/dmt/), 2008
[^2]: Randi, J. (1983) The Project Alpha experiment: Part one: the first two years. *Skeptical Inquirer*, Summer issue, Pages 24-33
[^3]: Randi, J. (1983) The Project Alpha Experiment: Part two: Beyond the Laboratory,” *Skeptical Inquirer* Fall issue, Pages 36-45
[^prtr]: Hyman, R.. "Parapsychological research: A tutorial review and critical appraisal". Retrieved on 20 September, 2008.
[^NAS]: Druckman, D. and Swets, J. A. eds. (1988). Enhancing Human Performance: Issues, Theories and Techniques. National Academy Press, Washington, D.C., 22. ISBN 0-309-07465-7.
[^Melton]: Melton, J. G. (1996). Parapsychology. In Encyclopedia of Occultism & Parapsychology. Thomson Gale. ISBN 978-0810394872.
[^Beloff]: Beloff, John (1977). Handbook of parapsychology. Van Nostrand Reinhold. ISBN 0442295766.
[^Berger]: Berger, Arthur S.; Berger, Joyce (1991). The Encyclopedia of Parapsychology and Psychical Research. Paragon House Publishers. ISBN 1557780439.
[^Harvey]: Irwin, Harvey J. (2007). An Introduction to Parapsychology, Fourth Edition. McFarland & Company. ISBN 0786418338. Retrieved on 2007-07-31.
[^Smee]: Odling-Smee, Lucy (2007-03-01). "The lab that asked the wrong questions". Nature 446 (446): 10–11. doi:10.1038/446010a. Retrieved on 2007-06-29.
[^cardenza]: Cardena, Etzel (2004). *Varieties of Anomalous Experience: Examining the Scientific Evidence Recently at the PA annual convention and conference, AP members re-recognizing "the forgotten pioneers of parapsychology", thus re-examining and accepting the roles of additional contributors of parapsychology, overlooked over the years, that pertain to today.* American Psychological Association (APA). ISBN 1557986258.
[^Honorton]: Bem, Daryl J.; Honorton, Charles (1995). "Does psi exist? Replicable evidence for an anomalous process of information transfer" (PDF). Psychological Bulletin 115 (1): 4–18. doi:10.1037/0033-2909.115.1.4. Retrieved on 2007-07-31.
[^Carroll2]: Carroll, Robert Todd (2005). "psi assumption". Skepdic.com. The Skeptics Dictionary. Retrieved on 2007-07-30.
[^Wheeler]: John Archibald Wheeler (1998). Geons, Black Holes, and Quantum Foam: A Life in Physics. W. W. Norton. ISBN 0-39304-642-7.
[^Stenger]: Stenger, Victor J. (2002). "Meta-Analysis and the Filedrawer Effect". Committee for Skeptical Inquiry. Committee for Skeptical Inquiry. Retrieved on 2007-07-30.
[^pmid16822162]: Bösch H, Steinkamp F, Boller E (2006). "Examining psychokinesis: the interaction of human intention with random number generators—a meta-analysis". Psychological bulletin 132 (4): 497–523. doi:10.1037/0033-2909.132.4.497. PMID 16822162. “The study effect sizes were strongly and inversely related to sample size and were extremely heterogeneous. A Monte Carlo simulation revealed that the small effect size, the relation between sample size and effect size, and the extreme effect size heterogeneity found could in principle be a result of publication bias."
[^Dunne85]: Dunne, Brenda J.; Jahn, Robert G. (1985). "On the quantum mechanics of consciousness, with application to anomalous phenomena". Foundations of Physics 16 (8): 721–772. doi:10.1007/BF00735378. Retrieved on 2007-07-31.
[^Dunne]: Dunne, Brenda; Jahn, Robert G. (2003). "Does psi exist? Replicable evidence for an anomalous process of information transfer". Journal of Scientific Exploration 17 (2): 207–241. Retrieved on 2007-07-31.
[^pmid16822164]: Radin, D.; Nelson, R.; Dobyns, Y.; Houtkooper, J. (2006). "Reexamining psychokinesis: comment on Bösch, Steinkamp, and Boller". Psychological bulletin 132 (4): 529–32; discussion 533–37. doi:10.1037/0033-2909.132.4.529. PMID 16822164.
[^pmid15142304]: Schmidt, S.; Schneider, R.; Utts, J.; Walach, H. (2004). "Distant intentionality and the feeling of being stared at: two meta-analyses". British journal of psychology (London, England : 1953) 95 (Pt 2): 235–47. doi:10.1348/000712604773952449. PMID 15142304.
[^Mauro]: Mauro, James (1992). "Bright lights, big mystery". Psychology Today. Retrieved on 2007-07-31.
[^Gracely]: Gracely, Ph.D., Ed J. (1998). "Why Extraordinary Claims Demand Extraordinary Proof". PhACT. Retrieved on 2007-07-31.
[^Moulton]: Moulton ST, Kosslyn SM (January 2008). "Using neuroimaging to resolve the psi debate". Journal of cognitive neuroscience 20 (1): 182–92. doi:10.1162/jocn.2008.20.1.182. PMID 18095790. Retrieved on 2008-10-13.
[^Beyerstein]: Beyerstein, Barry L. (1995). "Distinguishing Science from Pseudoscience" (PDF). Simon Fraser University. Retrieved on 2007-07-31.
[^Hyman]: Hyman, Ray (1995). "Evaluation of the program on anomalous mental phenomena". The Journal of Parapsychology 59 (1). Retrieved on 2007-07-30.
[^Alcock81]: Alcock, J. E. (1981). Parapsychology, Science or Magic?. Pergamon Press. ISBN 0080257720.
[^Alcock98]: Alcock, J. E. (1998). "Science, pseudoscience, and anomaly". Behavioral and Brain Sciences.
[^Alcock03]: Alcock, James E.; Jahn, Robert G. (2003). "Give the Null Hypothesis a Chance" (PDF). Journal of Consciousness Studies 10 (6-7): 29–50. Retrieved on 2007-07-30.
[^Haskell]: Scott, C.; Haskell, P. (1973). "'Normal' Explanation of the Soal-Goldney Experiments in Extrasensory Perception". Nature 245 (5419): 52–54. doi:10.1038/245052a0. Retrieved on 2007-07-31.
[^Markwick]: Markwick, B; Haskell, P. (1978). "The Soal-Goldney experiments with Basil Shackleton: new evidence of data manipulation". Proc Soc Psychical Res 56: 250–277.
[^Houdini]: Houdini, Harry (1987). A Magician Among the Spirits. Arno Press.
[^Akers]: Akers, C.. "Methodological Criticisms of Parapsychology, Advances in Parapsychological Research 4". PesquisaPSI. Retrieved on 2007-07-30.
[^Hyman33]: Hyman, Ray (1996). "The Evidence for Psychic Functioning: Claims vs. Reality". CSICOP. Retrieved on 2007-07-02.
