The term **psychokinesis** (from the Greek
*ψυχή*, "psyche", meaning *mind, soul, heart, or breath*; and *κίνησις*,
"kinesis", meaning *motion*; literally "movement from the
mind"), also known as
**telekinesis**
(Greek ** + **, literally
"distant-movement"), sometimes abbreviated PK and TK respectively, is a
term coined by Henry
Holt[^1] to refer to the direct influence of mind on a
physical system that cannot be entirely
accounted for by the mediation of any known physical
energy.[^parapsych_glossary] Examples of psychokinesis could
include distorting or moving an object, or
influencing the output of a random number
generator.[^parapsych_glossary][^faqfile1]

The study of phenomena said to be psychokinetic is an aspect of
[[parapsychology]]. Some paranormal researchers
believe that psychokinesis exists and deserves further study, although
the focus of research has shifted away from large-scale phenomena to
attempts to influence dice and then to random number
generators.[^Bosch2006][^Hyman2007]

There is currently no unchallenged scientific
evidence that shows psychokinesis
exists.[^Vyse1997] A
meta-analysis of 380 studies in 2006 found a
"very small" effect which could be explained by publication
bias.[^Bosch2006] PK experiments have historically been
criticised for lack of proper controls and repeatability.[^girden1962][^Humphrey1995][^Carroll]
However, some experiments have created *illusions* of PK where none
exists, and these illusions depend to an extent on the subject's prior
belief in PK.[^Benassi1979][^Wiseman1995]

Terminology {#terminology}
-----------

### Early history {#early_history}

The term "Telekinesis" was coined in 1890 by Russian psychical
researcher Alexander N. Aksakof.[^2] The term
"Psychokinesis" was coined in 1914 by American
author-publisher Henry Holt in his book *On the Cosmic
Relations and adopted
by his friend, American parapsychologist [[J. B. Rhine]] in 1934 in connection with experiments to
determine if a person could influence the outcome of falling
dice.[^Spence] Both
concepts have been described by other terms, such as "remote influencing", "distant influencing", "remote
mental influence", "distant mental influence",[^Broughton] "directed conscious intention", " anomalous
perturbation", and "mind over matter."[^Berger] Originally telekinesis was coined to refer
to the movement of objects thought to be caused by
[[ghosts]] of deceased persons, mischievous
spirits, [[angels]],
[[demons]], or other
[[supernatural]] forces.[^Berger]
Later, when speculation increased that humans might be the source of the
witnessed phenomena not caused by fraudulent mediums
and could possibly cause movement without any connection to
a [[Spiritualism|spiritualistic]] setting, such as in a
darkened [[séance]] room, psychokinesis was added to
the lexicon.[^Berger] Eventually, psychokinesis became
the term preferred by the parapsychological community.[^Spence] Popular culture, however, such as movies, television,
and literature, over the years preferred telekinesis to describe the
paranormal movement of objects, likely due to the word's resemblance to
other terms, such as telepathy, teleportation, etc.

### Modern usage {#modern_usage}

As research entered the modern era, it became clear that many different,
but related, abilities could be attributed to the wider description of
psychokinesis and telekinesis are now regarded as the subspecialties of
PK. In the 2004 U.S. Air Force-sponsored research report *Teleportation
Physics Study*, the physicist-author Eric Davis, PhD, described the
distinction between PK and TK as "telekinesis is a form of
PK." Psychokinesis, then, is the general term
that can be used to describe a variety of complex mental force phenomena
(including object movement) and telekinesis is used to refer only to the
movement of objects, however tiny (a grain of salt or air molecules to
create wind)[^Guiley] or large (an
automobile, building, or bridge). Hypothetically, a person could have
very profound telekinetic ability, but not be able to produce any of the
additional effects found in psychokinesis, such as softening the metal
of a spoon to allow its bending with minimal physical force. Conversely,
someone who has succeeded in psychokinetically softening metal once or a
number of times may exhibit no telekinetic ability to move objects.

Measurement and observation {#measurement_and_observation}
---------------------------

[[Parapsychology]] researchers describe two
basic types of measurable and observable psychokinetic and telekinetic
effects in experimental laboratory research and in case reports
occurring outside of the laboratory.[^Berger][^Broughton] Micro-PK
(also micro-TK) is a very small effect, such as the manipulation of
molecules, atoms,[^Broughton] subatomic particles,[^Broughton] etc., that can only be observed with scientific
equipment. The words are abbreviations for micro-psychokinesis/
micropsychokinesis[^Guiley] and micro-telekinesis/
microtelekinesis. Macro-PK (also macro-TK) is a large-scale effect that
can be seen with the unaided eye. The adjective phrases
"microscopic-scale," "macroscopic- scale," "small-scale," and
"large-scale" may also be used; for example, "a small-scale PK effect."

### Spontaneous effects {#spontaneous_effects}

Spontaneous movements of objects and other unexplained effects have been
reported, possibly caused by forms of
psychokinesis/telekinesis.[^Berger][^Spence] Parapsychologist William G.
Roll coined the term "recurrent spontaneous
psychokinesis" (RSPK) in 1958.
The sudden movement of objects without deliberate intention
in the presence or vicinity of one or more witnesses is thought by some
to be related to as-yet-unknown PK/TK processes of the subconscious
mind.[^Guiley] Researchers use the term "PK agent,"
especially in spontaneous cases, to describe someone who is suspected of
being the source of the PK action.[^Guiley]
Outbreaks of spontaneous movements or other effects, such
as in a private home, and especially those involving violent or
physiological effects, such as objects hitting people or scratches or
other marks on the body, are sometimes investigated as
[[poltergeist]] cases.

Umbrella term {#umbrella_term}
-------------

Psychokinesis is the umbrella term for
various related specialty abilities, which may include:

* Telekinesis; movement of matter (micro and macro; move, lift, agitate, vibrate, spin, bend, break, or impact)
  * Speed up or slow down the naturally occurring vibrations of atoms in matter to alter temperature, possibly to the point of ignition
if combustible (also known as [[pyrokinesis]] and cryokinesis respectively).[^Genzmer]
  * Aerokinesis, the telekinetic subspecialty of being able to control the movement of air molecules specifically.[^Genzmer]
  * Hydrokinesis, the telekinetic subspecialty of being able to control the movement of water molecules specifically
  * Self [[levitation]] (rising in the air unsupported, flying).[^MindOverMatter]
* Object deformation (including metal softening and bending).
* Influencing events.[^MindOverMatter]
* Biological healing.
* [[Teleportation]] (disappearing and reappearing elsewhere)[^Guiley][^MindOverMatter]
* Phasing through matter.[^MindOverMatter]
* Transmutation of matter.[^MindOverMatter]
* [[Shapeshifting]]
* Energy shield (force field)
* Control of magnetism.[^MindOverMatter]
* Control of photons (light waves/particles)
* [[Thoughtform]] projection (a physically perceived person, animal, creature, object, ghostly entity, etc., created in the mind and projected into three-dimensional space and observable by others; for thought images allegedly placed on film, see [[Thoughtography]]).

Belief {#belief}
------

In September 2006, a survey about belief in various religious and
paranormal topics conducted by phone and mail-in questionnaire
polled Americans on their belief in telekinesis. Of
these participants, 28% of male participants and 31% of female
participants selected "agree" or "strongly agree" with the statement
"*It is possible to influence the world through the mind alone*". There
were 1,721 participants, and the poll had a margin of error of plus or
minus
4%.[^3]

In April 2008, British psychologist and skeptic Richard
Wiseman published the results of an online
survey he conducted entitled "Magicians and the Paranormal: A Survey,"
in which 400 magicians worldwide participated. For the question
"Do you believe that psychokinesis exists (i.e., that some
people can, by paranormal means, apply a noticeable force to an object
or alter its physical characteristics)?", the results were as
follows: No 83.5%, Yes 9%, Uncertain 7.5%. (Published April
23, 2008.)

### Notable claimants of psychokinetic or telekinetic ability {#notable_claimants_of_psychokinetic_or_telekinetic_ability}

-   Uri Geller (1946 – ), the Israeli famous
    for his spoon bending demonstrations,
    allegedly by PK.[^Berger] Geller has been caught many
    times using sleight of hand and according to
    author Terence Hines, all his effects have been recreated using
    conjuring tricks.
-   Nina Kulagina (1926 – 1990), alleged
    Soviet psychic of the late 1960s and early 1970s.[^Berger]
-   Felicia Parise, an American medical
    laboratory technician who allegedly was able to repeatedly
    demonstrate telekinetic movement of small objects beginning in the
    1970s, in the first reported instance spontaneously, and then with
    practice by intense conscious intention. She said her inspiration
    for making the attempt was in viewing the black-and-white films of
    Nina Kulagina performing similar feats.[^MindOverMatter] Some of the items Parise reportedly caused
    movement in were a plastic pill container, compass needle, and
    pieces of aluminum foil (the latter two under a bell
    jar] filmed by a magician).[^Broughton] During the height of her fame in the early 1970s, the *National Enquirer* tabloid newspaper in the United States,
    then printed in all black and white, featured her in a large photo
    on its cover seated at a table attempting to perform telekinesis
    with the headline: "First American to Move Objects with the Mind."
    Parise eventually retired from performing telekinesis due to the
    physical stress on her body.[^Broughton]
-   Eusapia Palladino (alternate
    spelling: Eusapia Paladino; 1854 - 1918) was an Italian medium who
    allegedly could cause objects to move during seances and was
    endorsed by world-famous magician Howard Thurston (1869 – 1936), who witnessed
    her levitation of a table.[^4]
-   Swami Rama (1925 – 1996), a
    yogi skilled in controlling his heart functions
    who was studied at the Menninger
    Foundation in the spring and fall
    of 1970, and was alleged by some observers at the foundation to have
    telekinetically moved a knitting needle twice from a distance of
    five feet. Although Swami Rama wore a facemask and gown to prevent allegations that he moved the needle with his breath or body movements,
and air vents in the room had been covered, Elmer Green, a physician observer who was present at the time was not convinced and expressed the
opinion that air movement was somehow the cause.

-   Many of India's "godmen" (Hindi ascetic) have
    claimed macro-PK abilities and demonstrated apparently miraculous
    phenomena in public, although as more controls are put in place to
    prevent trickery, fewer phenomena are produced.

### Notable witnesses to PK events {#notable_witnesses_to_pk_events}

Alleged psychokinetic events have been witnessed by psychologists in the
United States,[^9][^DeanRadin][^PamelaHeath] and in the U.S. and elsewhere in the
world by professionals with medical degrees,[^MichaelCrichton][^PamelaHeath] physicists,[^5]
electrical engineers,[^DeanRadin] military
personnel,[^6]
police officers,[^7] and other professionals and ordinary
citizens. Robert M. Schoch PhD, professor
at Boston University, has written "I do believe that some psychokinesis
is real" referring to the evidence for micro-psychokinesis obtained by
the Princeton PEAR laboratory experiments and similar studies and some
reports of macro-RSPK observed in poltergeist cases. He reports once
seeing a book "jumping off a shelf" while in a room where a female
psychokinesis agent was also present.
Best-selling author and medical doctor Michael
Crichton described what he termed a
"successful experience" with psychokinesis at a "spoon bending party" in
his 1988 book *Travels*.[^MichaelCrichton] Senior
Scientist at the Institute of Noetic
Sciences, author Dean
Radin has reported that he, like Michael
Crichton, was able to bend the bowl of a spoon over with unexplained
ease of force with witnesses present at a different informal PK
experiment gathering. He described his experience in his 2006 book
*Entangled Minds: Extrasensory Experiences in a Quantum Reality* and
online (with photos).[^DeanRadin]

### PK Parties {#pk_parties}

"PK Parties" were a cultural fad in the 1980s, where groups of people
were guided through rituals and chants to awaken metal-bending powers.
They were encouraged to shout at the items of cutlery they had brought
and to jump and scream to create an atmosphere of pandemonium (or what
scientific investigators called heightened suggestibility). Critics were
excluded and participants were told to avoid looking at their hands.
Thousands of people attended these emotionally charged parties, and many
became convinced that they had bent silverware by paranormal
means.

Scientific controversy {#scientific_controversy}
----------------------

If PK were to exist as claimed by some experimenters, it would violate
some well-established laws of physics, including the [[inverse square law]], the [[second law of thermodynamics]] and the
[[conservation of momentum]].[^Gilovich] Hence scientists have demanded a high standard of
evidence for PK, in line with Marcello
Truzzi's dictum "Extraordinary claims
require extraordinary proof".[^Humphrey1995][^Sutherland] When apparent PK can be produced in
ordinary ways—by trickery, special effects or by poor experimental
design—scientists accept that explanation as more
parsimonious than to accept that the laws of
physics should be rewritten.[^Broughton]

The late [[Carl Sagan]] included telekinesis in a
long list of "offerings of pseudoscience and superstition" which "it
would be foolish to accept (...) without solid scientific data" though
even highly improbable claims may possibly be eventually verified. He
placed the [[burden of proof]] on the
proponents, but cautioned readers to "await-or, much better, to
seek-supporting or disconfirming evidence" for claims that have
not been resolved either way. Physicist Richard
Feynman advocated a similar
position.

In their 1991 research paper *Biological Utilization of Quantum
Nonlocality*, Nobel Prize laureate Brian
Josephson and coauthor Fotini
Pallikara-Viras proposed that explanations for both psychokinesis and
telepathy might be found in quantum physics.[^8]

There is a broad consensus, including several proponents of
parapsychology, that PK research, and parapsychology more generally, has
not produced a reliable, repeatable demonstration.[^Vyse1997][^park2000][^Humphrey1995]

In 1984, the United States National Academy of
Sciences, at the
request of the US Army Research Institute, formed a scientific panel to
assess the best evidence from 130 years of parapsychology. Part of its
purpose was to investigate military applications of PK, for example to
remotely jam or disrupt enemy weaponry. The panel heard from a variety
of military staff who believed in PK and made visits to the PEAR
laboratory and
two other laboratories that had claimed positive results from micro-PK
experiments.

The panel criticized macro-PK experiments for being open to deception by
conjurors, and said that virtually all micro-PK experiments "depart from
good scientific practice in a variety of ways". Their conclusion,
published in a 1987 report, was that there was no scientific evidence
for the existence of psychokinesis. Parapsychology advocates responded
by accusing the panel of bias.

Research with random number generators has been influenced by signal
detection theory, viewing the
effect of PK as weak but real "signal" hidden in the "noise" of
experimental results. An effect too weak to be demonstrated in a
replicable experiment would still show up as a statistically significant
effect in a large set of data. To test this, parapsychologists have
carried out meta-analyses of large data
sets, with apparently impressive positive
results. This has in turn been criticized as an
invalid use of meta-analysis, since the original studies are too
dissimilar for the resulting statistics to be meaningful.[^Hyman2007] A 2006 meta-analysis of 380 studies found a small
positive effect within the margin that could be explained by
publication bias.[^Bosch2006]

Physicist Robert L. Park finds it
suspicious that a phenomenon should only ever appear at the limits of
detectability of questionable statistical techniques. He cites this
feature as one of Irving Langmuir's
indicators of pathological science.
Park argues that if PK really existed it would be easily and
unambiguously detectable, for example using modern
microbalances which can detect tiny amounts
of force.[^park2000]

PK hypotheses are also tested implicitly in a number of contexts outside
parapsychological experiments. Gardner considers a dice game played in
casinos, where gamblers have a large incentive to affect the numbers
that come up. This is in effect a large sample-size test of the same
hypothesis as the J. B. Rhine dice experiments, but year after year the
house takings are exactly those predicted by
chance. Psychologist Nicholas
Humphrey argues that many experiments in
psychology, biology or
physics assume that the intentions of the subjects
or experimenter do *not* physically distort the apparatus. Humphrey
counts them as replications of PK experiments (but implicitly so) in
which PK fails to appear.[^Humphrey1995]

In the book *Parapsychology: The Controversial Science* (1991), British
parapsychologist Richard S. Broughton, Ph.D, wrote of the differences of
opinion among top scientists encountered by Robert G.
Jahn, director of the (now-closed) PEAR
laboratory,
regarding the psychokinesis research that the lab was engaged in at the
time.[^Broughton]

### Explanations in terms of bias {#explanations_in_terms_of_bias}

[[Cognitive bias]] research has been
interpreted to argue that people are susceptible to illusions of PK.
These include both the illusion that they themselves have the power, and
that events they witness are real demonstrations of PK.[^Blackmore psychic illusions] For example,
[[Illusion of control]] is an [[illusory correlation]] between intention and
external events, and believers in the paranormal have been shown to be
more susceptible to this illusion than skeptics.[^Benassi1979] Psychologist
Thomas Gilovich explains this as a biased
interpretation of personal experience. For example, to someone in a dice
game willing for a high score, high numbers can be interpreted as
"success" and low numbers as "not enough concentration."[^Gilovich] Bias towards belief in PK may be an
example of the [[Clustering illusion|human tendency to see patterns where none exist]], which believers are also more
susceptible to.[^Blackmore psychic illusions]

A 1952 study tested for experimenter's
bias in a PK context. Richard Kaufman
of Yale University gave subjects the task
of trying to influence 8 dice and allowed them to record their own
scores. They were secretly filmed, so their records could be checked for
errors. The results in each case were random and provided no evidence
for PK, but believers made errors that favored the PK hypothesis, while
disbelievers made opposite errors. A similar pattern of errors was found
in [[J. B. Rhine]]'s dice experiments which
at that time were the strongest evidence for PK.

Wiseman and Morris (1995) showed subjects an unedited videotape of a
magician's performance in which a fork bent and eventually broke.
Believers in the paranormal were significantly more likely to
misinterpret the tape as a demonstration of PK, and were more likely to
misremember crucial details of the presentation. This suggests that
[[confirmation bias]] affects people's
interpretation of PK demonstrations.[^Wiseman1995]
Psychologist Robert Sternberg cites
confirmation bias as an explanation of why belief in psi phenomena
persists, despite the lack of evidence: "People want to believe, and
so they find ways to believe."

On the problem of eyewitness testimony of alleged psychokinetic events,
anecdotes; that is, stories by
eyewitnesses outside of controlled laboratory conditions, are considered
insufficient evidence to establish the scientific validity of
psychokinesis.[^Broughton]

### Magic and special effects {#magic_and_special_effects}

Magicians, sleight-of-hand-artists, etc., have successfully simulated
some of the specialized abilities of PK (object movement, spoon
bending, levitation, teleportation), but not
all of the feats of claimed spontaneous and intentional psychokinesis
have been reproduced under the same observed conditions as the
original.[^Broughton] According to philosopher Robert
Todd Carroll, there are many impressive
magic tricks available to amateurs and professionals to simulate
psychokinetic powers. These can be purchased on
the Internet from magic supply companies. Metal objects such as keys or
cutlery can be bent by a number of different techniques, even if the
performer has not had access to them beforehand.
Amateur-made videos alleging to show feats of psychokinesis,
particularly spoon bending and the telekinetic movement of objects, can
be found on video-sharing websites such as YouTube. Critics point out
that it is now easier than ever for the average person to fake
psychokinetic events and that without more concrete proof, the topic,
apart from its enjoyment in fiction, will continue to remain
controversial.[^Genzmer]

The need for PK researchers to be aware of conjuring techniques was
illustrated by events in the early 1980s. The McDonnell Laboratory for
Psychical Research at Washington University reported a series of
experiments in which two subjects had demonstrated PK phenomena
(including metal-bending and causing images to appear on film) and other
psychic powers under laboratory conditions. Magician James
Randi revealed that the subjects were two of
his associates, amateur conjurers Steve Shaw and Michael Edwards. The
pair had created the effects by standard trickery, but the researchers,
being unfamiliar with magic techniques, interpreted them as proof of PK.
The laboratory closed not long after.

### Prize money for proof of psychokinesis {#prize_money_for_proof_of_psychokinesis}

Internationally, there are several individual skeptics of the paranormal
and skeptics'
organizations
who offer cash prize money for demonstration of the existence of an
extraordinary psychic power, such as psychokinesis. Experimental design
must be agreed upon prior to execution, and additional conditions, such
as a minimum level of fame, may be imposed. Prizes have been offered
specifically for PK demonstrations, for example, businessman Gerald
Fleming's offer of 250,000 pounds sterling
to Uri Geller if he can bend a spoon under controlled
conditions. These prizes remain uncollected by
people claiming to possess paranormal abilities.

The James Randi Educational
Foundation offers
1,000,000 US dollars to anyone who has a demonstrated media profile as
well as the support from some member of the academic community, and who
can produce a paranormal event, such as psychokinesis, in a controlled,
mutually agreed upon experiment.

Psychokinesis in religion, mythology, and popular culture {#psychokinesis_in_religion_mythology_and_popular_culture}
---------------------------------------------------------

### Religion and mythology

There are written accounts and oral legends of events fitting the
description of psychokinesis dating back to early history, most notably
in the stories found in various religions and mythology. In the Bible,
for example, Jesus is described as transmuting water into wine, which
"could be called psychokinesis", healing the
sick, and multiplying food.

Mythological beings, such as witches, have been accused of levitating
people, animals, and objects. The court wizard
and prophet Merlin in the King
Arthur legend, is said to have used his power
to transport [[Stonehenge]] across the sea to
England from Ireland.

### Popular culture

Psychokinesis has a well-established existence in movies, television,
computer games, literature, and other forms of popular culture. In the
1976 film *Carrie*, based on the
Stephen King novel of the same name, Sissy
Spacek portrayed a troubled high school
student with telekinetic powers. She was nominated for an Academy Award
for Best Actress, the first
psychokinetic character in a film ever to be so recognized (Ellen
Burstyn was the second, in 1980's
*Resurrection*). Numerous characters have the ability to control the
movement of objects using the "the
Force" in the *Star
Wars* canon. 

The comic book character Jean Grey of the
X-Men exhibits extremely powerful telekinetic
ability. It is
also commonly used as a power in a large number of
videogames and role playing
games.

See also {#see_also}
--------

-   [[Count of St Germain]]

-   [[Manifestation]]
-   [[Materialization]]
-   [[Wolf Messing]]

-   [[Precognition]]
-   [[Psi wheel]]
-   [[Psionics]]

-   [[Silva Method]]
-   [[Telepathy]]
-   [[Teleportation in Islam|Tai al-Ardh]]
-   [[Teleportation]]

Further reading {#further_reading}
---------------

-   ''The Conscious Universe: The Scientific Truth of Psychic Phenomena,
    ''Dean Radin, HarperEdge, 1997.
-   *Distant Mental Influence*, William Braud, Hampton Roads Publishing,
    Inc. , 2003. ISBN 1-57174-354-5. (largely a collection of published
    scientific research papers on formal experiments in psychokinesis
    conducted by the author with others between 1983 to 2000).
-   *Deception & Self-Deception: Investigating Psychics,* Richard
    Wiseman, Prometheus Books, 1997. ISBN 1-57392-121-1. Reports on
    investigations of macro-PK and also the effect of prior belief on
    interpretations of fake PK.
-   *Entangled Minds: Extrasensory Experiences in a Quantum Reality,*
    Dean Radin, Pocket Books, 2006.
-   *The Field: The Quest for the Secret Force of the Universe*, Lynne
    McTaggart, HarperCollins, 2008, updated
    paperback edition. ISBN 978-0-06-143518-8.
-   *Flim Flam!,* James Randi, Prometheus
    Books, 1982. ISBN 0-87975-198-3.
-   *Hauntings and Poltergeists: Multidisciplinary Perspectives,* James
    Houran and Rense Lange, editors; McFarland Press, 2001. A collection
    of science articles by leading researchers on documented ghost and
    spontaneous PK cases, with technical discussion also of possible
    methods of action for PK. ISBN 0786409843.
-   *How We Know What Isn't So: The fallibility of human reason in
    everyday life,* Thomas Gilovich, Simon
    & Schuster, 1993. ISBN 0029117062. Includes a chapter titled "Belief
    in ESP" and a subsection "Mundane Psychokinesis."

### Published Papers on PK / TK {#published_papers_on_pk_tk}

-   [The Journal of Non-Locality and Remote Mental Interactions](http://emergentmind.org/journal.htm) A journal of
    PK-related research papers published by EmergentMind.org.
-   [*Examining Psychokinesis: The Interaction of Human Intention With Random Number Generators – A Meta-Analysis*](http://www.ebo.de/publikationen/pk_ma.pdf) by Holger Bösch, Fiona Steinkamp, and Emil Boller, *Psychological Bulletin*,
    132, 497-523, 2006.
-   [*Solar-periodic full moon effect in the Fourmilab RetroPsychoKinesis Project experiment data: an exploratory study*](http://www.anomalistik.de/sdm_pdfs/etzold.pdf) by Eckhard Etzold *Journal of Parapsychology*, Fall 2005.
-   [*Does Psi Exist and Can We prove It: Belief and Disbelief in Psychokinesis Research*](http://m0134.fmg.uva.nl/research/PSI%20research/papers/39.pdf)
    by Eckhard Etzold, presented at the Parapsychological Association Convention 2004.
-   [*Material Deformation by Intention*](http://jackhouck.com/mdi.shtml) by Jack Houck, presented
    at the Science of Whole Person Healing Conference, March 28, 2003.
-   [*Can Our Intentions Interact Directly with the Physical World?*](http://integral-inquiry.com/docs/649/intentions.pdf) by
    William G. Braud, *European Journal of Parapsychology*, Vol. 10, 1994.
-   "A review of psychokinesis (PK)" by Edward Girden (1962).
    *Psychological Bulletin* 59 (5) pages 353-388 <doi:10.1037/h0048209>
-   [*The Persistent Paradox of Psychic Phenomena: An Engineering Perspective*](http://www.princeton.edu/~pear/pdfs/IEEE.pdf) by
    Robert G. Jahn, ''(1982) Proceedings IEEE, 70, No.2, pp.136-170. \]
-   ["Mind over matter: Perceived success at psychokinesis"](http://psycnet.apa.org/journals/psp/37/8/1377/) by
    Victor A. Benassi, Paul D. Sweeney, and Gregg E. Drevno (1979).
    *Journal of Personality and Social Psychology* 37 (8) pp.1377-1386.
    <doi:10.1037/0022-3514.37.8.1377>

### Military Papers on PK / TK {#military_papers_on_pk_tk}

-   [*Psychokinesis and Its Possible Implication to Warfare Strategy*](http://stinet.dtic.mil/oai/oai?&verb=getRecord&metadataPrefix=html&identifier=ADB097979)
    A 1985 study on potential military applications of psychokinesis by
    the U.S. Army Command and General Staff College, Fort Leavenworth,
    Kansas USA. Listed at the U.S. Defense Technical Information
    Center's website
    and available to the public through the U.S. National Technical
    Information Service.
-   [*Teleportation Physics Study*](http://www.fas.org/sgp/eprint/teleport.pdf) A study
    published in 2004 that reviews the current state research of real
    and hypothetical methods of teleportation. Includes a section titled
    *PK phenomenon*. Conducted by Eric Davis of Warp Drive Metrics,
    Nevada and sponsored by the U.S. Air Force Research Laboratory at
    Edwards AFB, California. Available publicly on the Federation of
    American Scientists website.
-   [*New Correlation Between a Human Subject and a Quantum Mechanical Random Number Generator*](http://stinet.dtic.mil/oai/oai?&verb=getRecord&metadataPrefix=html&identifier=AD0667953)
    A 1967 study by Helmut Schmidt conducted at the Boeing Scientific
    Research Laboratory in Seattle, Washington USA that concluded: "From
    the results, it is tentatively concluded that there exists a weak
    but significant correlation between the statistical processes
    operative in these experiments and the experimenter who initiates
    the processes." Listed at the U.S. Defense Technical Information
    Center's website
    and available to the public through the U.S. National Technical
    Information Service.

External links {#external_links}
--------------

-   ["The Princeton Engineering Anomalies Research (PEAR)"](http://skepdic.com/pear.html) entry in the online edition
    of the *Skeptic's Dictionary* by philosopher Robert Todd Carroll.

-   [Online Telekinesis Test](http://www.psychic-experiences.com/psychic-tests/telekinesis-test.php)

-   [The Intention Experiment](http://theintentionexperiment.com/the_experiments.htm) A
    series of scientifically controlled, web-based PK experiments.

-   [Mind Over Matter Study](http://www.rhine.org) An invitation by the
    Rhine Research Center of Durham, North Carolina USA to submit
    reports of PK or TK as part of an academic research study.

-   [Hollywood Telekinesis and Psychokinesis Movie List](http://jamesaconrad.tripod.com/TK-movie-list.html) Includes
    the "List of Cultural References to Psychokinesis and Telekinesis"
    that was formerly on Wikipedia.

References {#references}
----------

[^1]: Holt, Henry, *On the Cosmic Relation* - Book II- Part III, Psychokinesis, pp.216-217
[^2]: "The Oxford English Dictionary, Second Edition", 1989, Clarendon Press, Oxford, England, ISBN 0-19-861229-X
[^3]: <http://www.baylor.edu/content/services/document.php/33304.pdf> Study conducted by the Gallup Organization between October 8, 2005 and
December 12, 2005 on behalf of the Baylor Institute for Studies of Religion, Baylor University, of Waco, Texas, in the United States.
[^4]: [Text of entire book](http://books.google.com/books?hl=en&id=IqSDMEYSJPEC&dq=%22psychic+experiences+of+famous+people%22&printsec=frontcover&source=web&ots=HjCAB02RH-&sig=L0ADK8cZoGF0QT-tNo2nxcD280Y#PPA56,M1)
[^DeanRadin]: <http://www.deanradin.com/spoon.htm>
[^MichaelCrichton]: <http://www.crichton-official.com/features/spoonbending.html>
[^5]: John B. Hasted (1921-2002), PhD, Physics professor, University of London. In his book *The Metal-Benders*, he describes his research of psychokinesis claimants and psychokinesis events he personally witnessed.
[^6]: "In 1979, a secret unit was established by the most gifted minds within the US Army. Defying all known accepted
military practice—and indeed, the laws of physics-they believed that a soldier could adopt a cloak of invisibility, pass
cleanly through walls, and, perhaps most chillingly, kill goats just by staring at them."; "Lenny from Special Forces disappeared into the room
where the goat was. He came back and answered, with surprise and solemnity, "The goat is down.'" In reality, Fort
Bragg, by 1978, was already a hotbed of mind-war experimentation. Among the programs carried out at remote corners of the sprawling special
operations base: the Goat Lab, where a team of New Age- trained Special Forces soldiers attempted to burst the hearts of goats, in an adjacent
holding pen, through the power of psychic concentration." Article available online at
[<http://www.uri-geller.com/articles/2005/august/eir.htm>](http://www.uri-geller.com/articles/2005/august/eir.htm). The 2009 feature-film comedy *The Men Who Stare at Goats* explored this history.
[^7]: Two police officers witnessed alleged psychokinetic activity in the Resch home in the 1984 Columbus poltergeist case.
[^8]: *Foundations in Physics*, Vol. 21, pp. 197-207, 1991, Plenum Press, New York.
[^parapsych_glossary]: "[Parapsychological Association, glossary of key words frequently used in parapsychology](http://parapsych.org/glossary_l_r.html#p)". Retrieved on December 20, 2006.
[^faqfile1]: "[Parapsychological Association FAQ](http://www.parapsych.org/faq_file1.html)". Parapsychological Association (1995). Retrieved on 2007-07-02.
[^Bosch2006]: Bösch, Holger; Fiona Steinkamp, Emil Boller (July 2006). "Examining psychokinesis: The interaction of human intention with random number generators--A meta-analysis". Psychological Bulletin 132 (4): 497–523. doi:10.1037/0033-2909.132.4.497. Retrieved on 2008-11-17.
[^Hyman2007]: Hyman, Ray (2007). "Evaluating Parapsychological Claims", in Robert J. Sternberg, Henry L. Roediger, Diane F. Halpern: Critical Thinking in Psychology. Cambridge University Press, 218. ISBN 0521608341.
[^Vyse1997]: Vyse, Stuart A. (1997). Believing in Magic: The Psychology of Superstition. Oxford University Press US, 129. ISBN 0195136349. "[M]ost scientists, both psychologists and physicists, agree that it has yet to be convincingly demonstrated."
[^girden1962]: Girden, Edward (September 1962). "A review of psychokinesis (PK)". Psychological Bulletin 59 (5): 353–388. doi:10.1037/h0048209.
[^Humphrey1995]: Humphrey, Nicholas K. (1995). Soul Searching: Human nature and supernatural belief. Chatto & Windus. ISBN 0-7011-5963-4.
[^Carroll]: Carroll, Robert Todd (2005). "psychokinesis (PK)". Skepdic.com. The Skeptics Dictionary. Retrieved on 2007-10-05.
[^Benassi1979]: Benassi, Victor A.; Paul D. Sweeney, and Gregg E. Drevno (1979). "Mind over matter: Perceived success at psychokinesis". Journal of Personality and Social Psychology 37 (8): 1377–1386. doi:10.1037/0022-3514.37.8.1377. Retrieved on 2008-11-16.
[^Wiseman1995]: Wiseman, Richard; Robert Morris (1995). "Recalling pseudo-psychic demonstrations". British Journal of Psychology 86 (1): 113–125. Retrieved on 2008-11-29.
[^Broughton]: Broughton, Richard S. (1991). Parapsychology: The Controversial Science. New York: Ballantine Books, 35, 75–79, 149, 161–162, 329–330. ISBN 0-345-35638-1.
[^Berger]: Berger, Arthur S.; Berger, Joyce (1991). The Encyclopedia of Parapsychological and Psychical Research. New York: Paragon House, 326, 341, 430. ISBN 1-55778-043-9.
[^Spence]: Spence, Lewis (1920). Encyclopedia of Occultism and Parapsychology. Kessinger Publishing (reprint publisher), 752–753, 879, 912, 933. ISBN 0-7661-2817-2
[^Guiley]: Guiley, Rosemary Ellen (1991). Encyclopedia of the Strange, Mystical & Unexplained. New York: Gramercy Books, 454, 456, 478, 609. ISBN 0-517-16278-4.
[^MindOverMatter]: Time-Life Books. (1988). Mind Over Matter (volume of Mysteries of the Unknown encyclopedia series). New York: Time-Life Books, 7–8, 27, 82, 85. ISBN 0-8094-6336-9. OCLC 17877875
[^Genzmer]: Genzmer, Herbert; Hellenbrand, Ulrich (2007). "Psychokinesis", Mysteries of the World: Unexplained Wonders and Mysterious Phenomena. Bath, United Kingdom: Parragon Books Ltd, 194. ISBN 978-1-4054-9022-1.
[^9]: Roll, William G.; Storey, Valerie (2004). Unleashed — Of Poltergeists and Murder: The Curious Story of Tina Resch. New York: Paraview Pocket Books/Simon and Schuster. ISBN 0-7434-8294-8. OCLC 55117933. William G. Roll, PhD, and Jeannie Lagle (Masters degree) both state that they witnessed psychokinesis involving Tina Resch. Roll additionally reports numerous other cases he investigated.
[^PamelaHeath]: "[Official website of Pamela Heath](http://pamelaheath.com/about.htm)". Retrieved on June 9, 2007.
[^Gilovich]: Gilovich, Thomas (1993). How We Know What Isn't So: The fallibility of human reason in everyday life. Simon & Schuster, 174-175. ISBN 0029117062.
[^Sutherland]: Sutherland, Stuart (1994). Irrationality: the enemy within. Penguin books, 309. ISBN 0-14-016726-9. “[T]he movement of objects without the application of physical force would, if proven, require a complete revision of the laws of physics. (...) [T]he more improbable something is, the better the evidence needed to accept it”
[^park2000]: Park, Robert L. (2000). Voodoo Science: The road from foolishness to fraud. Oxford University Press, 198–200. ISBN 0-19-860443-2.
[^Blackmore psychic illusions]: Blackmore, Susan J. (1992). "Psychic Experiences: Psychic Illusions". Skeptical Inquirer 16: 367–376.